@@ -4,16 +4,16 @@
   This file is distributed under the GNU Public License, version 2 or at
   your option any later version. Read the file gpl.txt for details.
  
-  Create Blank .ST/.MSA Disc Images
+  Create blank .ST/.MSA disk images.
 */
-char CreateBlankImage_rcsid[] = "Hatari $Id: createBlankImage.c,v 1.10 2004/04/30 19:23:45 thothy Exp $";
+char CreateBlankImage_rcsid[] = "Hatari $Id: createBlankImage.c,v 1.13 2005/09/13 01:10:09 thothy Exp $";
 
 #include "main.h"
 #include "configuration.h"
 #include "dim.h"
 #include "file.h"
 #include "floppy.h"
-#include "misc.h"
+#include "log.h"
 #include "msa.h"
 #include "st.h"
 #include "createBlankImage.h"
@@ -41,11 +41,11 @@ char CreateBlankImage_rcsid[] = "Hatari $Id: createBlankImage.c,v 1.10 2004/04/3
 
 /*-----------------------------------------------------------------------*/
 /*
-  Calculate the size of a disc in dialog
+  Calculate the size of a disk in dialog.
 */
-static int CreateBlankImage_GetDiscImageCapacity(int nTracks, int nSectors, int nSides)
+static int CreateBlankImage_GetDiskImageCapacity(int nTracks, int nSectors, int nSides)
 {
-	/* Find size of disc image */
+	/* Find size of disk image */
 	return nTracks*nSectors*nSides*NUMBYTESPERSECTOR;
 }
 
@@ -53,7 +53,7 @@ static int CreateBlankImage_GetDiscImageCapacity(int nTracks, int nSectors, int
 /*-----------------------------------------------------------------------*/
 /*
   Write a short integer to addr using little endian byte order
-  (needed for 16 bit values in the bootsector of the disc image).
+  (needed for 16 bit values in the bootsector of the disk image).
 */
 static inline void WriteShortLE(void *addr, Uint16 val)
 {
@@ -66,52 +66,52 @@ static inline void WriteShortLE(void *addr, Uint16 val)
 
 /*-----------------------------------------------------------------------*/
 /*
-  Create .ST/.MSA disc image according to 'Tracks,Sector,Sides' and save as filename
+  Create .ST/.MSA disk image according to 'Tracks,Sector,Sides' and save as filename
 */
 void CreateBlankImage_CreateFile(char *pszFileName, int nTracks, int nSectors, int nSides)
 {
-	Uint8 *pDiscFile;
-	unsigned long DiscSize;
-	unsigned short int SPC, DIR, MediaByte, SPF;
+	Uint8 *pDiskFile;
+	unsigned long nDiskSize;
+	unsigned short int SPC, nDir, MediaByte, SPF;
 	BOOL bRet=FALSE;
 
-	/* Calculate size of disc image */
-	DiscSize = CreateBlankImage_GetDiscImageCapacity(nTracks, nSectors, nSides);
+	/* Calculate size of disk image */
+	nDiskSize = CreateBlankImage_GetDiskImageCapacity(nTracks, nSectors, nSides);
 
 	/* Allocate space for our 'file', and blank */
-	pDiscFile = malloc(DiscSize);
-	if (pDiscFile == NULL)
+	pDiskFile = malloc(nDiskSize);
+	if (pDiskFile == NULL)
 	{
-		perror("Error while creating blank disc image");
+		perror("Error while creating blank disk image");
 		return;
 	}
-	memset(pDiscFile, 0, DiscSize);                       /* Clear buffer */
+	memset(pDiskFile, 0, nDiskSize);                      /* Clear buffer */
 
 	/* Fill in boot-sector */
-	pDiscFile[0] = 0xE9;                                  /* Needed for MS-DOS compatibility */
-	memset(pDiscFile+2, 0x4e, 6);                         /* 2-7 'Loader' */
+	pDiskFile[0] = 0xE9;                                  /* Needed for MS-DOS compatibility */
+	memset(pDiskFile+2, 0x4e, 6);                         /* 2-7 'Loader' */
 
-	WriteShortLE(pDiscFile+8, rand());                    /* 8-10 24-bit serial number */
-	pDiscFile[10] = rand();
+	WriteShortLE(pDiskFile+8, rand());                    /* 8-10 24-bit serial number */
+	pDiskFile[10] = rand();
 
-	WriteShortLE(pDiscFile+11, NUMBYTESPERSECTOR);        /* 11-12 BPS */
+	WriteShortLE(pDiskFile+11, NUMBYTESPERSECTOR);        /* 11-12 BPS */
 
 	if ((nTracks == 40) && (nSides == 1))
 		SPC = 1;
 	else
 		SPC = 2;
-	pDiscFile[13] = SPC;                                  /* 13 SPC */
+	pDiskFile[13] = SPC;                                  /* 13 SPC */
 
-	WriteShortLE(pDiscFile+14, 1);                        /* 14-15 RES */
-	pDiscFile[16] = 2;                                    /* 16 FAT */
+	WriteShortLE(pDiskFile+14, 1);                        /* 14-15 RES */
+	pDiskFile[16] = 2;                                    /* 16 FAT */
 
 	if (SPC==1)
-		DIR = 64;
+		nDir = 64;
 	else
-		DIR = 112;
-	WriteShortLE(pDiscFile+17, DIR);                      /* 17-18 DIR */
+		nDir = 112;
+	WriteShortLE(pDiskFile+17, nDir);                     /* 17-18 DIR */
 
-	WriteShortLE(pDiscFile+19, nTracks*nSectors*nSides);  /* 19-20 SEC */
+	WriteShortLE(pDiskFile+19, nTracks*nSectors*nSides);  /* 19-20 SEC */
 
 	if (nTracks <= 42)
 		MediaByte = 0xFC;
@@ -119,49 +119,49 @@ void CreateBlankImage_CreateFile(char *pszFileName, int nTracks, int nSectors, i
 		MediaByte = 0xF8;
 	if (nSides == 2)
 		MediaByte |= 0x01;
-	pDiscFile[21] = MediaByte;                            /* 21 MEDIA */
+	pDiskFile[21] = MediaByte;                            /* 21 MEDIA */
 
 	if (nTracks >= 80)
 		SPF = 5;
 	else
 		SPF = 2;
-	WriteShortLE(pDiscFile+22, SPF);                      /* 22-23 SPF */
+	WriteShortLE(pDiskFile+22, SPF);                      /* 22-23 SPF */
 
-	WriteShortLE(pDiscFile+24, nSectors);                 /* 24-25 SPT */
-	WriteShortLE(pDiscFile+26, nSides);                   /* 26-27 SIDE */
-	WriteShortLE(pDiscFile+28, 0);                        /* 28-29 HID */
+	WriteShortLE(pDiskFile+24, nSectors);                 /* 24-25 SPT */
+	WriteShortLE(pDiskFile+26, nSides);                   /* 26-27 SIDE */
+	WriteShortLE(pDiskFile+28, 0);                        /* 28-29 HID */
 
 	/* Set correct media bytes in the 1st FAT: */
-	pDiscFile[512] = MediaByte;
-	pDiscFile[513] = pDiscFile[514] = 0xFF;
+	pDiskFile[512] = MediaByte;
+	pDiskFile[513] = pDiskFile[514] = 0xFF;
 	/* Set correct media bytes in the 2nd FAT: */
-	pDiscFile[512 + SPF * 512] = MediaByte;
-	pDiscFile[513 + SPF * 512] = pDiscFile[514 + SPF * 512] = 0xFF;
+	pDiskFile[512 + SPF * 512] = MediaByte;
+	pDiskFile[513 + SPF * 512] = pDiskFile[514 + SPF * 512] = 0xFF;
 
 	/* Ask if OK to overwrite, if exists? */
 	if (File_QueryOverwrite(pszFileName))
 	{
 		/* Save image to file */
 		if (MSA_FileNameIsMSA(pszFileName, TRUE))
-			bRet = MSA_WriteDisc(pszFileName, pDiscFile, DiscSize);
+			bRet = MSA_WriteDisk(pszFileName, pDiskFile, nDiskSize);
 		else if (ST_FileNameIsST(pszFileName, TRUE))
-			bRet = ST_WriteDisc(pszFileName, pDiscFile, DiscSize);
+			bRet = ST_WriteDisk(pszFileName, pDiskFile, nDiskSize);
 		else if (DIM_FileNameIsDIM(pszFileName, TRUE))
-			bRet = DIM_WriteDisc(pszFileName, pDiscFile, DiscSize);
+			bRet = DIM_WriteDisk(pszFileName, pDiskFile, nDiskSize);
 
 		/* Did create successfully? */
 		if (bRet)
 		{
 			/* Say OK, */
-			Main_Message("Disc image created successfully.", PROG_NAME /*,MB_OK | MB_ICONINFORMATION*/);
+			Log_AlertDlg(LOG_INFO, "Disk image has been created successfully.");
 		}
 		else
 		{
 			/* Warn user we were unable to create image */
-			Main_Message("Unable to create disc image!", PROG_NAME /*,MB_OK | MB_ICONSTOP*/);
+			Log_AlertDlg(LOG_ERROR, "Unable to create disk image!");
 		}
 	}
 
 	/* Free image */
-	free(pDiscFile);
+	free(pDiskFile);
 }
