@@ -6,7 +6,7 @@
 
   Common file access functions.
 */
-char File_rcsid[] = "Hatari $Id: file.c,v 1.16 2004/10/31 17:32:50 thothy Exp $";
+char File_rcsid[] = "Hatari $Id: file.c,v 1.24 2005/09/13 01:10:09 thothy Exp $";
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -18,11 +18,7 @@ char File_rcsid[] = "Hatari $Id: file.c,v 1.16 2004/10/31 17:32:50 thothy Exp $"
 #include "main.h"
 #include "dialog.h"
 #include "file.h"
-#include "floppy.h"
 #include "createBlankImage.h"
-#include "memAlloc.h"
-#include "misc.h"
-
 
 
 #if defined(__BEOS__) || (defined(__sun) && defined(__SVR4))
@@ -49,7 +45,7 @@ char File_rcsid[] = "Hatari $Id: file.c,v 1.16 2004/10/31 17:32:50 thothy Exp $"
 */
 int alphasort(const void *d1, const void *d2)
 {
-  return(strcmp((*(struct dirent **)d1)->d_name, (*(struct dirent **)d2)->d_name));
+  return strcmp((*(struct dirent * const *)d1)->d_name, (*(struct dirent * const *)d2)->d_name);
 }
 
 
@@ -57,12 +53,12 @@ int alphasort(const void *d1, const void *d2)
 /*
   Scan a directory for all its entries
 */
-int scandir(const char *dirname, struct dirent ***namelist, int (*select)(struct dirent *), int (*dcomp)(const void *, const void *))
+int scandir(const char *dirname, struct dirent ***namelist, int (*sdfilter)(struct dirent *), int (*dcomp)(const void *, const void *))
 {
-  register struct dirent *d, *p, **names;
-  register size_t nitems;
+  struct dirent *d, *p, **names;
   struct stat stb;
-  long arraysz;
+  size_t nitems;
+  size_t arraysz;
   DIR *dirp;
 
   if ((dirp = opendir(dirname)) == NULL)
@@ -85,7 +81,7 @@ int scandir(const char *dirname, struct dirent ***namelist, int (*select)(struct
 
   while ((d = readdir(dirp)) != NULL) {
 
-     if (select != NULL && !(*select)(d))
+     if (sdfilter != NULL && !(*sdfilter)(d))
        continue;       /* just selected names */
 
      /*
@@ -128,7 +124,7 @@ int scandir(const char *dirname, struct dirent ***namelist, int (*select)(struct
 
    *namelist = names;
 
-   return(nitems);
+   return nitems;
 }
 
 
@@ -166,7 +162,8 @@ void File_CleanFileName(char *pszFileName)
 void File_AddSlashToEndFileName(char *pszFileName)
 {
   /* Check dir/filenames */
-  if (strlen(pszFileName)!=0) {
+  if (strlen(pszFileName)!=0)
+  {
     if (pszFileName[strlen(pszFileName)-1]!='/')
       strcat(pszFileName,"/");  /* Must use end slash */
   }
@@ -177,7 +174,7 @@ void File_AddSlashToEndFileName(char *pszFileName)
 /*
   Does filename extension match? If so, return TRUE
 */
-BOOL File_DoesFileExtensionMatch(char *pszFileName, char *pszExtension)
+BOOL File_DoesFileExtensionMatch(const char *pszFileName, const char *pszExtension)
 {
   if ( strlen(pszFileName) < strlen(pszExtension) )
     return(FALSE);
@@ -212,7 +209,7 @@ BOOL File_IsRootFileName(char *pszFileName)
 /*
   Return string, to remove 'C:' part of filename
 */
-char *File_RemoveFileNameDrive(char *pszFileName)
+const char *File_RemoveFileNameDrive(const char *pszFileName)
 {
   if ( (pszFileName[0]!='\0') && (pszFileName[1]==':') )
     return(&pszFileName[2]);
@@ -250,8 +247,10 @@ void File_RemoveFileNameTrailingSlashes(char *pszFileName)
 
   /* Do have slash at end of filename? */
   Length = strlen(pszFileName);
-  if (Length>=3) {
-    if (pszFileName[Length-1]=='/') {     /* Yes, have one previous? */
+  if (Length>=3)
+  {
+    if (pszFileName[Length-1]=='/')       /* Yes, have one previous? */
+    {
       if (pszFileName[Length-2]=='/')
         pszFileName[Length-1] = '\0';     /* then remove it! */
     }
@@ -261,10 +260,10 @@ void File_RemoveFileNameTrailingSlashes(char *pszFileName)
 
 /*-----------------------------------------------------------------------*/
 /*
-  Read file from disc into memory, allocate memory for it if need to (pass
+  Read file from disk into memory, allocate memory for it if need to (pass
   Address as NULL).
 */
-void *File_Read(char *pszFileName, void *pAddress, long *pFileSize, char *ppszExts[])
+void *File_Read(char *pszFileName, void *pAddress, long *pFileSize, const char *ppszExts[])
 {
   void *pFile = NULL;
   long FileSize = 0;
@@ -307,15 +306,15 @@ void *File_Read(char *pszFileName, void *pAddress, long *pFileSize, char *ppszEx
   }
   else
   {
-    FILE *hDiscFile;
+    FILE *hDiskFile;
     /* Open and read normal file */
-    hDiscFile = fopen(pszFileName, "rb");
-    if (hDiscFile != NULL)
+    hDiskFile = fopen(pszFileName, "rb");
+    if (hDiskFile != NULL)
     {
       /* Find size of file: */
-      fseek(hDiscFile, 0, SEEK_END);
-      FileSize = ftell(hDiscFile);
-      fseek(hDiscFile, 0, SEEK_SET);
+      fseek(hDiskFile, 0, SEEK_END);
+      FileSize = ftell(hDiskFile);
+      fseek(hDiskFile, 0, SEEK_SET);
       /* Find pointer to where to load, allocate memory if pass NULL */
       if (pAddress)
         pFile = pAddress;
@@ -323,9 +322,9 @@ void *File_Read(char *pszFileName, void *pAddress, long *pFileSize, char *ppszEx
         pFile = malloc(FileSize);
       /* Read in... */
       if (pFile)
-        fread(pFile, 1, FileSize, hDiscFile);
+        fread(pFile, 1, FileSize, hDiskFile);
 
-      fclose(hDiscFile);
+      fclose(hDiskFile);
     }
   }
 
@@ -339,7 +338,7 @@ void *File_Read(char *pszFileName, void *pAddress, long *pFileSize, char *ppszEx
 
 /*-----------------------------------------------------------------------*/
 /*
-  Save file to disc, return FALSE if errors
+  Save file to disk, return FALSE if errors
 */
 BOOL File_Save(char *pszFileName, void *pAddress, size_t Size, BOOL bQueryOverwrite)
 {
@@ -362,7 +361,7 @@ BOOL File_Save(char *pszFileName, void *pAddress, size_t Size, BOOL bQueryOverwr
     if (hGzFile != NULL)
     {
       /* Write data, set success flag */
-      if (gzwrite(hGzFile, pAddress, Size) == Size)
+      if (gzwrite(hGzFile, pAddress, Size) == (int)Size)
         bRet = TRUE;
 
       gzclose(hGzFile);
@@ -370,16 +369,16 @@ BOOL File_Save(char *pszFileName, void *pAddress, size_t Size, BOOL bQueryOverwr
   }
   else
   {
-    FILE *hDiscFile;
+    FILE *hDiskFile;
     /* Create a normal file: */
-    hDiscFile = fopen(pszFileName, "wb");
-    if (hDiscFile != NULL)
+    hDiskFile = fopen(pszFileName, "wb");
+    if (hDiskFile != NULL)
     {
       /* Write data, set success flag */
-      if (fwrite(pAddress, 1, Size, hDiscFile) == Size)
+      if (fwrite(pAddress, 1, Size, hDiskFile) == Size)
         bRet = TRUE;
 
-      fclose(hDiscFile);
+      fclose(hDiskFile);
     }
   }
 
@@ -391,16 +390,18 @@ BOOL File_Save(char *pszFileName, void *pAddress, size_t Size, BOOL bQueryOverwr
 /*
   Return size of file, -1 if error
 */
-int File_Length(char *pszFileName)
+int File_Length(const char *pszFileName)
 {
-  FILE *DiscFile;
+  FILE *hDiskFile;
   int FileSize;
-  DiscFile = fopen(pszFileName, "rb");
-  if (DiscFile!=NULL) {
-    fseek(DiscFile, 0, SEEK_END);
-    FileSize = ftell(DiscFile);
-    fseek(DiscFile, 0, SEEK_SET);
-    fclose(DiscFile);
+
+  hDiskFile = fopen(pszFileName, "rb");
+  if (hDiskFile!=NULL)
+  {
+    fseek(hDiskFile, 0, SEEK_END);
+    FileSize = ftell(hDiskFile);
+    fseek(hDiskFile, 0, SEEK_SET);
+    fclose(hDiskFile);
     return(FileSize);
   }
 
@@ -412,38 +413,27 @@ int File_Length(char *pszFileName)
 /*
   Return TRUE if file exists
 */
-BOOL File_Exists(char *pszFileName)
+BOOL File_Exists(const char *pszFileName)
 {
-  FILE *DiscFile;
+  FILE *hDiskFile;
 
   /* Attempt to open file */
-  DiscFile = fopen(pszFileName, "rb");
-  if (DiscFile!=NULL) {
-    fclose(DiscFile);
+  hDiskFile = fopen(pszFileName, "rb");
+  if (hDiskFile!=NULL)
+  {
+    fclose(hDiskFile);
     return(TRUE);
   }
   return(FALSE);
 }
 
 
-/*-----------------------------------------------------------------------*/
-/*
-  Delete file, return TRUE if OK
-*/
-BOOL File_Delete(char *pszFileName)
-{
-  /* Delete the file (must be closed first) */
-  return( remove(pszFileName) );
-}
-
-
 /*-----------------------------------------------------------------------*/
 /*
   Find if file exists, and if so ask user if OK to overwrite
 */
-BOOL File_QueryOverwrite(char *pszFileName)
+BOOL File_QueryOverwrite(const char *pszFileName)
 {
-
   char szString[FILENAME_MAX + 26];
 
   /* Try and find if file exists */
@@ -463,32 +453,47 @@ BOOL File_QueryOverwrite(char *pszFileName)
 /*
   Try filename with various extensions and check if file exists - if so return correct name
 */
-BOOL File_FindPossibleExtFileName(char *pszFileName, char *ppszExts[])
+BOOL File_FindPossibleExtFileName(char *pszFileName, const char *ppszExts[])
 {
-  char szSrcDir[256], szSrcName[128], szSrcExt[32];
-  char szTempFileName[FILENAME_MAX];
-  int i=0;
+  char *szSrcDir, *szSrcName, *szSrcExt;
+  char *szTempFileName;
+  int i = 0;
+  BOOL bFileExists = FALSE;
+
+  /* Allocate temporary memory for strings: */
+  szTempFileName = malloc(4 * FILENAME_MAX);
+  if (!szTempFileName)
+  {
+    perror("File_FindPossibleExtFileName");
+    return FALSE;
+  }
+  szSrcDir = szTempFileName + FILENAME_MAX;
+  szSrcName = szSrcDir + FILENAME_MAX;
+  szSrcExt = szSrcName + FILENAME_MAX;
 
   /* Split filename into parts */
   File_splitpath(pszFileName, szSrcDir, szSrcName, szSrcExt);
 
   /* Scan possible extensions */
-  while(ppszExts[i]) {
+  while(ppszExts[i] && !bFileExists)
+  {
     /* Re-build with new file extension */
     File_makepath(szTempFileName, szSrcDir, szSrcName, ppszExts[i]);
     /* Does this file exist? */
-    if (File_Exists(szTempFileName)) {
+    if (File_Exists(szTempFileName))
+    {
       /* Copy name for return */
-      strcpy(pszFileName,szTempFileName);
-      return(TRUE);
+      strcpy(pszFileName, szTempFileName);
+      bFileExists = TRUE;
     }
 
     /* Next one */
     i++;
   }
 
-  /* No, none of the files exist */
-  return(FALSE);
+  free(szTempFileName);
+
+  return bFileExists;
 }
 
 
@@ -497,7 +502,7 @@ BOOL File_FindPossibleExtFileName(char *pszFileName, char *ppszExts[])
   Split a complete filename into path, filename and extension.
   If pExt is NULL, don't split the extension from the file name!
 */
-void File_splitpath(char *pSrcFileName, char *pDir, char *pName, char *pExt)
+void File_splitpath(const char *pSrcFileName, char *pDir, char *pName, char *pExt)
 {
   char *ptr1, *ptr2;
 
@@ -536,7 +541,7 @@ void File_splitpath(char *pSrcFileName, char *pDir, char *pName, char *pExt)
   Build a complete filename from path, filename and extension.
   pExt can also be NULL.
 */
-void File_makepath(char *pDestFileName, char *pDir, char *pName, char *pExt)
+void File_makepath(char *pDestFileName, const char *pDir, const char *pName, const char *pExt)
 {
   strcpy(pDestFileName, pDir);
   if( strlen(pDestFileName)==0 )
@@ -586,10 +591,16 @@ void File_ShrinkName(char *pDestFileName, char *pSrcFileName, int maxlen)
 */
 void File_MakeAbsoluteName(char *pFileName)
 {
-  char *pTempName = Memory_Alloc(FILENAME_MAX);
+  char *pTempName;
   int inpos, outpos;
 
   inpos = 0;
+  pTempName = malloc(FILENAME_MAX);
+  if (!pTempName)
+  {
+    perror("File_MakeAbsoluteName - malloc");
+	return;
+  }
 
   /* Is it already an absolute name? */
   if(pFileName[0] == '/')
@@ -598,7 +609,12 @@ void File_MakeAbsoluteName(char *pFileName)
   }
   else
   {
-    getcwd(pTempName, FILENAME_MAX);
+    if (!getcwd(pTempName, FILENAME_MAX))
+    {
+      perror("File_MakeAbsoluteName - getcwd");
+      free(pTempName);
+	  return;
+    }
     File_AddSlashToEndFileName(pTempName);
     outpos = strlen(pTempName);
   }
@@ -643,5 +659,40 @@ void File_MakeAbsoluteName(char *pFileName)
   pTempName[outpos] = 0;
 
   strcpy(pFileName, pTempName);          /* Copy back */
-  Memory_Free(pTempName);
+  free(pTempName);
+}
+
+
+/*-----------------------------------------------------------------------*/
+/*
+  Create a valid path name from a possibly invalid name by erasing invalid
+  path parts at the end of the string.
+  pPathName needs to point to a buffer of at least FILENAME_MAX bytes.
+*/
+void File_MakeValidPathName(char *pPathName)
+{
+  struct stat dirstat;
+  char *pLastSlash;
+
+  do
+  {
+    /* Check for a valid path */
+    if (stat(pPathName, &dirstat) == 0 && S_ISDIR(dirstat.st_mode))
+    {
+      break;
+    }
+
+    pLastSlash = strrchr(pPathName, '/');
+    if (pLastSlash)
+    {
+      /* Erase the (probably invalid) part after the last slash */
+      *pLastSlash = 0;
+    }
+    else
+    {
+      /* Path name seems to be completely invalid -> set to root directory */
+      strcpy(pPathName, "/");
+    }
+  }
+  while (pLastSlash);
 }
