@@ -6,7 +6,7 @@
 
   The main dialog.
 */
-char DlgMain_rcsid[] = "Hatari $Id: dlgMain.c,v 1.5 2004/12/05 23:30:19 thothy Exp $";
+char DlgMain_rcsid[] = "Hatari $Id: dlgMain.c,v 1.8 2005/09/13 01:10:09 thothy Exp $";
 
 #include "main.h"
 #include "configuration.h"
@@ -16,7 +16,7 @@ char DlgMain_rcsid[] = "Hatari $Id: dlgMain.c,v 1.5 2004/12/05 23:30:19 thothy E
 
 
 #define MAINDLG_ABOUT    2
-#define MAINDLG_DISCS    3
+#define MAINDLG_DISKS    3
 #define MAINDLG_ROM      4
 #define MAINDLG_SCREEN   5
 #define MAINDLG_SOUND    6
@@ -40,7 +40,7 @@ static SGOBJ maindlg[] =
   { SGBOX, 0, 0, 0,0, 36,22, NULL },
   { SGTEXT, 0, 0, 10,1, 16,1, "Hatari main menu" },
   { SGBUTTON, 0, 0, 4,4, 12,1, "About" },
-  { SGBUTTON, 0, 0, 4,6, 12,1, "Discs" },
+  { SGBUTTON, 0, 0, 4,6, 12,1, "Disks" },
   { SGBUTTON, 0, 0, 4,8, 12,1, "ROM" },
   { SGBUTTON, 0, 0, 4,10, 12,1, "Screen" },
   { SGBUTTON, 0, 0, 4,12, 12,1, "Sound" },
@@ -70,7 +70,7 @@ int Dialog_MainDlg(BOOL *bReset)
   BOOL bOldMouseVisibility;
   int nOldMouseX, nOldMouseY;
 
-  if(SDLGui_PrepareFont())
+  if(SDLGui_SetScreen(sdlscrn))
     return FALSE;
 
   SDL_GetMouseState(&nOldMouseX, &nOldMouseY);
@@ -84,14 +84,14 @@ int Dialog_MainDlg(BOOL *bReset)
 
   do
   {
-    retbut = SDLGui_DoDialog(maindlg);
+    retbut = SDLGui_DoDialog(maindlg, NULL);
     switch(retbut)
     {
       case MAINDLG_ABOUT:
         Dialog_AboutDlg();
         break;
-      case MAINDLG_DISCS:
-        Dialog_DiscDlg();
+      case MAINDLG_DISKS:
+        Dialog_DiskDlg();
         break;
       case MAINDLG_ROM:
         DlgRom_Main();
@@ -123,7 +123,7 @@ int Dialog_MainDlg(BOOL *bReset)
           /* Configuration_Load uses the variables from ConfigureParams.
            * That's why we have to temporarily back it up here */
           tmpParams = ConfigureParams;
-          Configuration_Load();
+          Configuration_Load(NULL);
           DialogParams = ConfigureParams;
           ConfigureParams = tmpParams;
         }
@@ -144,7 +144,7 @@ int Dialog_MainDlg(BOOL *bReset)
         break;
     }
   }
-  while(retbut!=MAINDLG_OK && retbut!=MAINDLG_CANCEL && !bQuitProgram);
+  while (retbut!=MAINDLG_OK && retbut!=MAINDLG_CANCEL && retbut!=SDLGUI_QUIT && !bQuitProgram);
 
 
   if( maindlg[MAINDLG_RESET].state & SG_SELECTED )
