@@ -6,22 +6,17 @@
 
   Low-level hard drive emulation
 */
-char HDC_rcsid[] = "Hatari $Id: hdc.c,v 1.6 2004/04/23 15:33:58 thothy Exp $";
+char HDC_rcsid[] = "Hatari $Id: hdc.c,v 1.9 2005/10/04 15:31:52 thothy Exp $";
 
 #include "main.h"
-#include "debug.h"
 #include "configuration.h"
+#include "debugui.h"
 #include "fdc.h"
 #include "hdc.h"
-#include "floppy.h"
-#include "ikbd.h"
-#include "m68000.h"
 #include "memorySnapShot.h"
 #include "mfp.h"
-#include "misc.h"
-#include "psg.h"
 #include "stMemory.h"
-#include "debugui.h"
+#include "tos.h"
 
 /*
   ACSI emulation: 
@@ -55,7 +50,7 @@ short int HDCSectorCount;
 /* 
   FDC registers used:
   - FDCSectorCountRegister
-  - DiscControllerStatus_ff8604rd
+  - DiskControllerStatus_ff8604rd
   - DMAModeControl_ff8606wr
 */
 
@@ -313,22 +308,20 @@ static void HDC_GetInfo(void)
 BOOL HDC_Init(char *filename)
 {
   if( (hd_image_file = fopen(filename, "r+")) == NULL)
-    return( FALSE );
+    return FALSE;
 
   HDC_GetInfo();
   if(!nPartitions) 
     {
       fclose( hd_image_file );
       hd_image_file = NULL;
-      ConfigureParams.HardDisc.bUseHardDiscImage = FALSE;
-      return( FALSE );
+      ConfigureParams.HardDisk.bUseHardDiskImage = FALSE;
+      return FALSE;
     }
   /* set number of partitions */
-  ConfigureParams.HardDisc.nDriveList += nPartitions;
+  nNumDrives += nPartitions;
 
-  ConfigureParams.HardDisc.bUseHardDiscImage = TRUE;
-
-  return( TRUE );
+  return TRUE;
 }
 
 /*---------------------------------------------------------------------*/
@@ -341,8 +334,8 @@ void HDC_UnInit(void)
   if(!(ACSI_EMU_ON)) return;
   fclose(hd_image_file);
   hd_image_file = NULL;
+  nNumDrives -= nPartitions;
   nPartitions = 0;
-  ConfigureParams.HardDisc.bUseHardDiscImage = FALSE;
 }
 
 /*---------------------------------------------------------------------*/
@@ -360,7 +353,7 @@ void HDC_WriteCommandPacket(void)
   if(!(ACSI_EMU_ON)) return;
 
   /* command byte sent, store it. */
-  HDCCommand.command[HDCCommand.byteCount++] =  (DiscControllerWord_ff8604wr&0xFF);
+  HDCCommand.command[HDCCommand.byteCount++] =  (DiskControllerWord_ff8604wr&0xFF);
   
   /* have we recived a complete 6-byte packet yet? */
   if(HDCCommand.byteCount >= 6){
