@@ -14,24 +14,23 @@
   in this game has a bug in it, which corrupts its own registers if more than one byte is queued up. This
   value was found by a test program on a real ST and has correctly emulated the behaviour.
 */
-char IKBD_rcsid[] = "Hatari $Id: ikbd.c,v 1.20 2004/11/14 02:34:31 thothy Exp $";
+char IKBD_rcsid[] = "Hatari $Id: ikbd.c,v 1.23 2005/04/05 14:41:26 thothy Exp $";
 
 #include <time.h>
 
 #include "main.h"
-#include "debug.h"
 #include "gemdos.h"
 #include "ikbd.h"
 #include "int.h"
+#include "ioMem.h"
 #include "joy.h"
 #include "m68000.h"
-#include "memAlloc.h"
 #include "memorySnapShot.h"
 #include "mfp.h"
 #include "misc.h"
 #include "screen.h"
 #include "video.h"
-#include "vdi.h"
+
 
 #define DBL_CLICK_HISTORY  0x07     /* Number of frames since last click to see if need to send one or two clicks */
 #define ACIA_CYCLES    7200         /* Cycles (Multiple of 4) between sent to ACIA from keyboard along serial line - 500Hz/64, (approx' 6920-7200cycles from test program) */
@@ -44,7 +43,7 @@ char IKBD_rcsid[] = "Hatari $Id: ikbd.c,v 1.20 2004/11/14 02:34:31 thothy Exp $"
 #define ABS_MAX_X_ONRESET  320      /* Initial absolute mouse limits after RESET command */
 #define ABS_MAY_Y_ONRESET  200      /* These values are never actually used as user MUST call 'IKBD_Cmd_AbsMouseMode' before ever using them */
 
-#define ABS_PREVBUTTONS    (0x02|0x8)  /* Don't report any buttons up on first call to 'IKBD_Cmd_ReadAbsMousePos' */
+#define ABS_PREVBUTTONS  (0x02|0x8) /* Don't report any buttons up on first call to 'IKBD_Cmd_ReadAbsMousePos' */
 
 
 /* Keyboard state */
@@ -60,10 +59,10 @@ BOOL bMouseDisabled, bJoystickDisabled;
 BOOL bDuringResetCriticalTime, bBothMouseAndJoy;
 
 /* ACIA */
-unsigned char ACIAControlRegister = 0;
-unsigned char ACIAStatusRegister = ACIA_STATUS_REGISTER__TX_BUFFER_EMPTY;  /* Pass when read 0xfffc00 */
-unsigned char ACIAByte;                 /* When a byte has arrived at the ACIA(from the keyboard) it is stored here */
-BOOL bByteInTransitToACIA = FALSE;      /* Is a byte being sent to the ACIA from the keyboard? */
+static Uint8 ACIAControlRegister = 0;
+static Uint8 ACIAStatusRegister = ACIA_STATUS_REGISTER__TX_BUFFER_EMPTY;  /* Pass when read 0xfffc00 */
+static Uint8 ACIAByte;                      /* When a byte has arrived at the ACIA (from the keyboard) it is stored here */
+static BOOL bByteInTransitToACIA = FALSE;   /* Is a byte being sent to the ACIA from the keyboard? */
 
 /*
   6850 ACIA (Asynchronous Communications Inferface Apdater)
@@ -147,7 +146,7 @@ BOOL bByteInTransitToACIA = FALSE;      /* Is a byte being sent to the ACIA from
 */
 
 /* List of possible keyboard commands, others are seen as NOPs by keyboard processor */
-IKBD_COMMAND_PARAMS KeyboardCommands[] = {
+static IKBD_COMMAND_PARAMS KeyboardCommands[] = {
   /* Known messages, counts include command byte */
   { 0x80,2,  IKBD_Cmd_Reset },
   { 0x07,2,  IKBD_Cmd_MouseAction },
@@ -229,7 +228,7 @@ void IKBD_Reset(BOOL bCold)
   /* And our keyboard states and clear key state table */
   Keyboard.BufferHead = Keyboard.BufferTail = 0;
   Keyboard.nBytesInInputBuffer = 0;
-  Memory_Clear(Keyboard.KeyStates,sizeof(Keyboard.KeyStates));
+  memset(Keyboard.KeyStates, 0, sizeof(Keyboard.KeyStates));
   Keyboard.bLButtonDown = BUTTON_NULL;
   Keyboard.bRButtonDown = BUTTON_NULL;
   Keyboard.bOldLButtonDown = Keyboard.bOldRButtonDown = BUTTON_NULL;
@@ -1343,12 +1342,12 @@ void IKBD_Cmd_Execute(void)
   For our emulation we bypass the ACIA (I've yet to see anything check for this)
   and add the byte directly into the keyboard input buffer.
 */
-static void IKBD_RunKeyboardCommand(unsigned short ACIAByte)
+static void IKBD_RunKeyboardCommand(unsigned short aciabyte)
 {
   int i=0;
 
   /* Write into our keyboard input buffer */
-  Keyboard.InputBuffer[Keyboard.nBytesInInputBuffer++] = ACIAByte;
+  Keyboard.InputBuffer[Keyboard.nBytesInInputBuffer++] = aciabyte;
 
   /* Now check bytes to see if we have a valid/in-valid command string set */
   while(KeyboardCommands[i].Command!=0xff) {
@@ -1487,3 +1486,42 @@ void IKBD_PressSTKey(unsigned char ScanCode,BOOL bPress)
     ScanCode |= 0x80;    /* Set top bit if released key */
   IKBD_AddKeyToKeyboardBuffer(ScanCode);  /* And send to keyboard processor */
 }
+
+
+/*-----------------------------------------------------------------------*/
+/*
+  Handle read from keyboard control ACIA register (0xfffc00)
+*/
+void IKBD_KeyboardControl_ReadByte(void)
+{
+	/* For our emulation send is immediate so acknowledge buffer is empty */
+	IoMem[0xfffc00] = ACIAStatusRegister | ACIA_STATUS_REGISTER__TX_BUFFER_EMPTY;
+}
+
+/*-----------------------------------------------------------------------*/
+/*
+  Handle read from keyboard data ACIA register (0xfffc02)
+*/
+void IKBD_KeyboardData_ReadByte(void)
+{
+	IoMem[0xfffc02] = IKBD_GetByteFromACIA();  /* Return our byte from keyboard processor */
+}
+
+
+/*-----------------------------------------------------------------------*/
+/*
+  Handle write to keyboard control ACIA register (0xfffc00)
+*/
+void IKBD_KeyboardControl_WriteByte(void)
+{
+	/* Nothing... */
+}
+
+/*-----------------------------------------------------------------------*/
+/*
+  Handle write to keyboard data ACIA register (0xfffc02)
+*/
+void IKBD_KeyboardData_WriteByte(void)
+{
+	IKBD_SendByteToKeyboardProcessor(IoMem[0xfffc02]);  /* Pass our byte to the keyboard processor */
+}
