@@ -9,6 +9,15 @@
 #define HATARI_CONFIGURATION_H
 
 
+/* Logging */
+typedef struct
+{
+  char sLogFileName[FILENAME_MAX];
+  int nTextLogLevel;
+  int nAlertDlgLogLevel;
+} CNF_LOG;
+
+
 /* ROM (TOS + cartridge) configuration */
 typedef struct
 {
@@ -59,55 +68,54 @@ typedef struct
 } CNF_KEYBOARD;
 
 
-/* Memory configuration */
-typedef enum
-{
-  MEMORY_SIZE_512Kb,
-  MEMORY_SIZE_1Mb,
-  MEMORY_SIZE_2Mb,
-  MEMORY_SIZE_4Mb
-} MEMORY_SIZE;
-
 typedef struct
 {
-  MEMORY_SIZE nMemorySize;
+  int nMemorySize;
   char szMemoryCaptureFileName[FILENAME_MAX];
 } CNF_MEMORY;
 
 
 /* Joystick configuration */
+typedef enum
+{
+  JOYSTICK_DISABLED,
+  JOYSTICK_REALSTICK,
+  JOYSTICK_KEYBOARD
+} JOYSTICKMODE;
+
 typedef struct
 {
-  BOOL bCursorEmulation;
+  JOYSTICKMODE nJoystickMode;
   BOOL bEnableAutoFire;
+  int nJoyId;
+  int nKeyCodeUp, nKeyCodeDown, nKeyCodeLeft, nKeyCodeRight, nKeyCodeFire;
 } JOYSTICK;
 
 typedef struct
 {
-  JOYSTICK Joy[2];
+  JOYSTICK Joy[6];
 } CNF_JOYSTICKS;
 
 
-/* Discimage configuration */
-typedef struct
-{
-  BOOL bAutoInsertDiscB;
-  char szDiscImageDirectory[FILENAME_MAX];
-} CNF_DISCIMAGE;
-
-
-/* Hard discs configuration */
-#define MAX_HARDDRIVES  1
-#define DRIVELIST_TO_DRIVE_INDEX(DriveList)  (DriveList+1)
+/* Disk image configuration */
 
 typedef enum
 {
-  DRIVELIST_NONE,
-  DRIVELIST_C,
-  DRIVELIST_CD,
-  DRIVELIST_CDE,
-  DRIVELIST_CDEF
-} DRIVELIST;
+  WRITEPROT_OFF,
+  WRITEPROT_ON,
+  WRITEPROT_AUTO
+} WRITEPROTECTION;
+
+typedef struct
+{
+  BOOL bAutoInsertDiskB;
+  WRITEPROTECTION nWriteProtection;
+  char szDiskImageDirectory[FILENAME_MAX];
+} CNF_DISKIMAGE;
+
+
+/* Hard drives configuration */
+#define MAX_HARDDRIVES  1
 
 typedef enum
 {
@@ -119,14 +127,13 @@ typedef enum
 
 typedef struct
 {
-  int nDriveList;
-  BOOL bBootFromHardDisc;
-  int nHardDiscDir;
-  BOOL bUseHardDiscDirectories;
-  BOOL bUseHardDiscImage;
-  char szHardDiscDirectories[MAX_HARDDRIVES][FILENAME_MAX];
-  char szHardDiscImage[FILENAME_MAX];
-} CNF_HARDDISC;
+  BOOL bBootFromHardDisk;
+  int nHardDiskDir;
+  BOOL bUseHardDiskDirectories;
+  BOOL bUseHardDiskImage;
+  char szHardDiskDirectories[MAX_HARDDRIVES][FILENAME_MAX];
+  char szHardDiskImage[FILENAME_MAX];
+} CNF_HARDDISK;
 
 
 /* Screen configuration */
@@ -173,12 +180,21 @@ typedef enum
   MINMAXSPEED_MAX
 } MINMAXSPEED_TYPE;
 
+typedef enum
+{
+  MACHINE_ST,
+  MACHINE_STE
+} MACHINETYPE;
+
 typedef struct
 {
   int nCpuLevel;
+  int nCpuFreq;
   BOOL bCompatibleCpu;
-  BOOL bAddressSpace24;
+  /*BOOL bAddressSpace24;*/
+  MACHINETYPE nMachineType;
   BOOL bBlitter;                  /* TRUE if blitter is enabled */
+  BOOL bRealTimeClock;
   BOOL bPatchTimerD;
   BOOL bSlowFDC;                  /* TRUE to slow down FDC emulation */
   MINMAXSPEED_TYPE nMinMaxSpeed;
@@ -190,13 +206,14 @@ typedef struct
 typedef struct
 {
   /* Configure */
+  CNF_LOG Log;
   CNF_SCREEN Screen;
   CNF_JOYSTICKS Joysticks;
   CNF_KEYBOARD Keyboard;
   CNF_SOUND Sound;
   CNF_MEMORY Memory;
-  CNF_DISCIMAGE DiscImage;
-  CNF_HARDDISC HardDisc;
+  CNF_DISKIMAGE DiskImage;
+  CNF_HARDDISK HardDisk;
   CNF_ROM Rom;
   CNF_RS232 RS232;
   CNF_PRINTER Printer;
@@ -211,7 +228,7 @@ extern char sConfigFileName[FILENAME_MAX];
 
 extern void Configuration_SetDefault(void);
 extern void Configuration_WorkOnDetails(BOOL bReset);
-extern void Configuration_Load(void);
+extern void Configuration_Load(const char *psFileName);
 extern void Configuration_Save(void);
 
 #endif
