@@ -20,11 +20,11 @@ extern void Dialog_AboutDlg(void);
 extern int DlgAlert_Notice(const char *text);
 extern int DlgAlert_Query(const char *text);
 extern void Dialog_DeviceDlg(void);
-extern void Dialog_DiscDlg(void);
+extern void Dialog_DiskDlg(void);
 extern void Dialog_JoyDlg(void);
 extern void Dialog_KeyboardDlg(void);
 extern void Dialog_MemDlg(void);
-extern void DlgNewDisc_Main(void);
+extern void DlgNewDisk_Main(void);
 extern void Dialog_ScreenDlg(void);
 extern void Dialog_SoundDlg(void);
 extern void Dialog_SystemDlg(void);
