@@ -14,30 +14,30 @@ typedef struct
   Uint8 *pBuffer;
   char szFileName[FILENAME_MAX];
   int nImageBytes;
-  BOOL bDiscInserted;
+  BOOL bDiskInserted;
   BOOL bMediaChanged;
   BOOL bContentsChanged;
   BOOL bOKToSave;
 } EMULATION_DRIVE;
 
 #define NUM_EMULATION_DRIVES  2            /* A:, B: */
-#define NUMBYTESPERSECTOR    512           /* All discs are 512 bytes per sector */
+#define NUMBYTESPERSECTOR    512           /* All disks are 512 bytes per sector */
 
 extern EMULATION_DRIVE EmulationDrives[NUM_EMULATION_DRIVES];
 extern int nBootDrive;
-extern char *pszDiscImageNameExts[];
 
 extern void Floppy_Init(void);
 extern void Floppy_UnInit(void);
 extern void Floppy_MemorySnapShot_Capture(BOOL bSave);
 extern void Floppy_GetBootDrive(void);
-extern BOOL Floppy_InsertDiscIntoDrive(int Drive, char *pszFileName);
-extern BOOL Floppy_ZipInsertDiscIntoDrive(int Drive, char *pszFileName, char *pszZipPath);
-extern void Floppy_EjectDiscFromDrive(int Drive,BOOL bInformUser);
+extern BOOL Floppy_IsWriteProtected(int Drive);
+extern BOOL Floppy_InsertDiskIntoDrive(int Drive, char *pszFileName);
+extern BOOL Floppy_ZipInsertDiskIntoDrive(int Drive, char *pszFileName, char *pszZipPath);
+extern void Floppy_EjectDiskFromDrive(int Drive,BOOL bInformUser);
 extern void Floppy_EjectBothDrives(void);
-extern void Floppy_FindDiscDetails(unsigned char *pBuffer,int nImageBytes,unsigned short int *pnSectorsPerTrack,unsigned short int *pnSides);
-extern BOOL Floppy_ReadSectors(int Drive,char *pBuffer,unsigned short int Sector,unsigned short int Track,unsigned short int Side, short int Count, int *pnSectorsPerTrack);
-extern BOOL Floppy_WriteSectors(int Drive,char *pBuffer,unsigned short int Sector,unsigned short int Track,unsigned short int Side, short int Count, int *pnSectorsPerTrack);
+extern void Floppy_FindDiskDetails(const Uint8 *pBuffer, int nImageBytes, unsigned short *pnSectorsPerTrack, unsigned short *pnSides);
+extern BOOL Floppy_ReadSectors(int Drive, Uint8 *pBuffer, unsigned short Sector, unsigned short Track, unsigned short Side, short Count, int *pnSectorsPerTrack);
+extern BOOL Floppy_WriteSectors(int Drive, Uint8 *pBuffer, unsigned short Sector, unsigned short Track, unsigned short Side, short Count, int *pnSectorsPerTrack);
 extern int Floppy_GetPhysicalSectorsPerTrack(int Drive);
 extern BOOL Floppy_ReadPhysicalSector(int Drive,char *pBuffer,unsigned short int Sector,unsigned short int Track,unsigned short int Side,unsigned short int Count);
 
