@@ -56,7 +56,7 @@
 #define GEMDOS_FILE_ATTRIB_WRITECLOSE    0x20
 
 /*
-  Disc Tranfer Address (DTA)
+  Disk Tranfer Address (DTA)
 */
 #define TOS_NAMELEN  14
 
@@ -112,7 +112,7 @@ extern void GemDOS_Reset(void);
 extern void GemDOS_InitDrives(void);
 extern void GemDOS_UnInitDrives(void);
 extern void GemDOS_MemorySnapShot_Capture(BOOL bSave);
-extern void GemDOS_CreateHardDriveFileName(int Drive,char *pszFileName,char *pszDestName);
+extern void GemDOS_CreateHardDriveFileName(int Drive, const char *pszFileName, char *pszDestName);
 extern BOOL GemDOS(void);
 extern void GemDOS_OpCode(void);
 extern void GemDOS_RunOldOpCode(void);
