@@ -20,9 +20,10 @@
 extern void *PendingInterruptFunction;
 extern short int PendingInterruptCount;
 
-extern Uint32 BusAddressLocation;
+extern Uint32 BusErrorAddress;
 extern Uint32 BusErrorPC;
 extern BOOL bBusErrorReadWrite;
+extern int nCpuFreqShift;
 
 
 /*-----------------------------------------------------------------------*/
@@ -32,15 +33,14 @@ extern BOOL bBusErrorReadWrite;
 */
 static inline void M68000_AddCycles(int cycles)
 {
-  cycles = (cycles + 3) & ~3;
-  PendingInterruptCount -= cycles;
-  SoundCycles += cycles;
+	cycles = ((cycles + 3) & ~3) >> nCpuFreqShift;
+	PendingInterruptCount -= cycles;
+	SoundCycles += cycles;
 }
 
 extern void M68000_Reset(BOOL bCold);
 extern void M68000_MemorySnapShot_Capture(BOOL bSave);
-extern void M68000_BusError(unsigned long addr, BOOL bReadWrite);
-extern void M68000_AddressError(unsigned long addr);
+extern void M68000_BusError(Uint32 addr, BOOL bReadWrite);
 extern void M68000_Exception(Uint32 ExceptionVector);
 extern void M68000_WaitState(void);
 
