@@ -10,10 +10,8 @@
 
 typedef int BOOL;
 
-#define PROG_NAME      "Hatari v0.60" /* Name, version for window title */
-#define PROG_VERSION   "v0.60"
-
-/*#define DEBUG_TO_FILE*/             /* Use debug.txt files */
+#define PROG_NAME      "Hatari v0.80" /* Name, version for window title */
+#define PROG_VERSION   "v0.80"
 
 
 #include <stdio.h>
@@ -25,8 +23,6 @@ typedef int BOOL;
 #include <SDL_types.h>
 
 
-#define MAX_STRING_LENGTH  512
-
 #ifndef FALSE
 #define FALSE 0
 #define TRUE (!0)
@@ -61,26 +57,26 @@ enum {
 };
 
 /* 68000 Condition code's */
-#define SR_AUX      0x0010
-#define SR_NEG      0x0008
-#define SR_ZERO      0x0004
-#define SR_OVERFLOW    0x0002
-#define SR_CARRY    0x0001
+#define SR_AUX              0x0010
+#define SR_NEG              0x0008
+#define SR_ZERO             0x0004
+#define SR_OVERFLOW         0x0002
+#define SR_CARRY            0x0001
 
-#define SR_CLEAR_AUX    0xffef
-#define SR_CLEAR_NEG    0xfff7
-#define SR_CLEAR_ZERO    0xfffb
-#define SR_CLEAR_OVERFLOW  0xfffd
-#define SR_CLEAR_CARRY    0xfffe
+#define SR_CLEAR_AUX        0xffef
+#define SR_CLEAR_NEG        0xfff7
+#define SR_CLEAR_ZERO       0xfffb
+#define SR_CLEAR_OVERFLOW   0xfffd
+#define SR_CLEAR_CARRY      0xfffe
 
-#define SR_CCODE_MASK    (SR_AUX|SR_NEG|SR_ZERO|SR_OVERFLOW|SR_CARRY)
-#define SR_MASK      0xFFE0
+#define SR_CCODE_MASK       (SR_AUX|SR_NEG|SR_ZERO|SR_OVERFLOW|SR_CARRY)
+#define SR_MASK             0xFFE0
 
-#define SR_TRACEMODE    0x8000
-#define SR_SUPERMODE    0x2000
-#define SR_IPL      0x0700
+#define SR_TRACEMODE        0x8000
+#define SR_SUPERMODE        0x2000
+#define SR_IPL              0x0700
 
-#define SR_CLEAR_IPL    0xf8ff
+#define SR_CLEAR_IPL        0xf8ff
 #define SR_CLEAR_TRACEMODE  0x7fff
 #define SR_CLEAR_SUPERMODE  0xdfff
 
@@ -137,9 +133,10 @@ enum {
 
 /* Assumes 32 pixels left+right */
 #define SCREENBYTES_LEFT    16          /* Bytes for left border in ST screen */
-#define SCREENBYTES_MIDDLE  160         /* Middle(320 pixels) */
+#define SCREENBYTES_MIDDLE  160         /* Middle (320 pixels) */
 #define SCREENBYTES_RIGHT   16          /* right border */
 #define SCREENBYTES_LINE    (SCREENBYTES_LEFT+SCREENBYTES_MIDDLE+SCREENBYTES_RIGHT)
+#define SCREENBYTES_MONOLINE 80         /* Byte per line in ST-high resolution */
 
 /* Overscan values */
 #define OVERSCAN_LEFT       (SCREENBYTES_LEFT*2)    /* Number of pixels in each border */
@@ -169,13 +166,10 @@ enum {
 extern BOOL bQuitProgram;
 extern BOOL bEnableDebug;
 extern BOOL bEmulationActive;
-extern char szBootDiscImage[FILENAME_MAX];
 extern char szWorkingDir[FILENAME_MAX];
 
 
 extern void Main_MemorySnapShot_Capture(BOOL bSave);
-extern void Main_SysError(char *Error,char *Title);
-extern int Main_Message(char *pText, char *pCaption);
 extern void Main_PauseEmulation(void);
 extern void Main_UnPauseEmulation(void);
 extern void Main_WarpMouse(int x, int y);
