@@ -14,13 +14,13 @@
 
 extern BOOL bWriteEnvelopeFreq,bWriteChannelAAmp,bWriteChannelBAmp,bWriteChannelCAmp;
 extern BOOL bEnvelopeFreqFlag;
-extern char MixBuffer[MIXBUFFER_SIZE];
+extern Sint8 MixBuffer[MIXBUFFER_SIZE];
 extern int SoundCycles;
 extern int nGeneratedSamples;
 
 extern void Sound_Init(void);
 extern void Sound_Reset(void);
-extern void Sound_ClearMixBuffer(void);
+extern void Sound_ResetBufferIndex(void);
 extern void Sound_MemorySnapShot_Capture(BOOL bSave);
 extern void Sound_Update(void);
 extern void Sound_Update_VBL(void);
