@@ -20,8 +20,8 @@ extern BOOL ZIP_FileNameIsZIP(char *pszFileName);
 extern struct dirent **ZIP_GetFilesDir(zip_dir *files, char *dir, int *entries);
 extern void ZIP_FreeZipDir(zip_dir *zd);
 extern zip_dir *ZIP_GetFiles(char *pszFileName);
-extern Uint8 *ZIP_ReadDisc(char *pszFileName, char *pszZipPath, long *pImageSize);
-extern BOOL ZIP_WriteDisc(char *pszFileName,unsigned char *pBuffer,int ImageSize);
+extern Uint8 *ZIP_ReadDisk(char *pszFileName, char *pszZipPath, long *pImageSize);
+extern BOOL ZIP_WriteDisk(char *pszFileName,unsigned char *pBuffer,int ImageSize);
 
 
 #endif  /* HATARI_ZIP_H */
