@@ -6,12 +6,10 @@
 
   Here we process a key press and the remapping of the scancodes.
 */
-char Keymap_rcsid[] = "Hatari $Id: keymap.c,v 1.16 2004/04/19 08:53:33 thothy Exp $";
+char Keymap_rcsid[] = "Hatari $Id: keymap.c,v 1.22 2005/09/26 18:24:09 thothy Exp $";
 
 #include "main.h"
-#include "debug.h"
 #include "keymap.h"
-#include "memAlloc.h"
 #include "misc.h"
 #include "configuration.h"
 #include "ikbd.h"
@@ -236,9 +234,9 @@ static const char SymbolicKeyToSTScanCode[SDLK_LAST] =
   -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, /* 128-143*/
   -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, /* 144-159*/
   -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, /* 160-175*/
-  -1, -1, -1, -1, 0x0d, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, /* 176-191*/
+  -1, -1, -1, -1, 0x0D, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, /* 176-191*/
   -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, /* 192-207*/
-  -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, /* 208-223*/
+  -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 0x0C, /* 208-223*/
   -1, -1, -1, -1, 0x28, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, /* 224-239*/
   -1, -1, -1, -1, -1, -1, 0x27, -1, -1, -1, -1, -1, 0x1A, -1, -1, -1, /* 240-255*/
   /* Numeric keypad: */
@@ -341,7 +339,7 @@ static char DebounceExtendedKeys[] =
 */
 void Keymap_Init(void)
 {
-  Memory_Clear(SdlSymToSdlScan, sizeof(SdlSymToSdlScan));
+  memset(SdlSymToSdlScan, 0, sizeof(SdlSymToSdlScan));      /* Clear array */
   Keymap_LoadRemapFile(ConfigureParams.Keyboard.szMappingFileName);
 }
 
@@ -349,7 +347,9 @@ void Keymap_Init(void)
 /*-----------------------------------------------------------------------*/
 /*
   Heuristic analysis to find out the obscure scancode offset.
-  This clever code has been taken from the emulator Aranym. (cheers!)
+  Some keys like 'z' can't be used for detection since they are on different
+  locations on "qwertz" and "azerty" keyboards.
+  This clever code has originally been taken from the emulator Aranym. (cheers!)
 */
 static int Keymap_FindScanCodeOffset(SDL_keysym* keysym)
 {
@@ -375,17 +375,17 @@ static int Keymap_FindScanCodeOffset(SDL_keysym* keysym)
     case SDLK_TAB:  offset = scanPC - 0x0f; break;
     case SDLK_RETURN:  offset = scanPC - 0x1c; break;
     case SDLK_SPACE:  offset = scanPC - 0x39; break;
-    case SDLK_q:  offset = scanPC - 0x10; break;
-    case SDLK_w:  offset = scanPC - 0x11; break;
+    /*case SDLK_q:  offset = scanPC - 0x10; break;*/  /* different on azerty */
+    /*case SDLK_w:  offset = scanPC - 0x11; break;*/  /* different on azerty */
     case SDLK_e:  offset = scanPC - 0x12; break;
     case SDLK_r:  offset = scanPC - 0x13; break;
     case SDLK_t:  offset = scanPC - 0x14; break;
-    case SDLK_y:  offset = scanPC - 0x15; break;
+    /*case SDLK_y:  offset = scanPC - 0x15; break;*/  /* different on qwertz */
     case SDLK_u:  offset = scanPC - 0x16; break;
     case SDLK_i:  offset = scanPC - 0x17; break;
     case SDLK_o:  offset = scanPC - 0x18; break;
     case SDLK_p:  offset = scanPC - 0x19; break;
-    case SDLK_a:  offset = scanPC - 0x1e; break;
+    /*case SDLK_a:  offset = scanPC - 0x1e; break;*/  /* different on azerty */
     case SDLK_s:  offset = scanPC - 0x1f; break;
     case SDLK_d:  offset = scanPC - 0x20; break;
     case SDLK_f:  offset = scanPC - 0x21; break;
@@ -394,13 +394,13 @@ static int Keymap_FindScanCodeOffset(SDL_keysym* keysym)
     case SDLK_j:  offset = scanPC - 0x24; break;
     case SDLK_k:  offset = scanPC - 0x25; break;
     case SDLK_l:  offset = scanPC - 0x26; break;
-    case SDLK_z:  offset = scanPC - 0x2c; break;
+    /*case SDLK_z:  offset = scanPC - 0x2c; break;*/  /* different on qwertz and azerty */
     case SDLK_x:  offset = scanPC - 0x2d; break;
     case SDLK_c:  offset = scanPC - 0x2e; break;
     case SDLK_v:  offset = scanPC - 0x2f; break;
     case SDLK_b:  offset = scanPC - 0x30; break;
     case SDLK_n:  offset = scanPC - 0x31; break;
-    case SDLK_m:  offset = scanPC - 0x32; break;
+    /*case SDLK_m:  offset = scanPC - 0x32; break;*/  /* different on azerty */
     case SDLK_CAPSLOCK:  offset = scanPC - 0x3a; break;
     case SDLK_LSHIFT:  offset = scanPC - 0x2a; break;
     case SDLK_LCTRL:  offset = scanPC - 0x1d; break;
@@ -473,7 +473,6 @@ static char Keymap_PcToStScanCode(SDL_keysym* keysym)
        * base offset (framebuffer = 0, X11 = 8).
        * Try to detect the offset using a little bit of black magic.
        * If offset is known then simply pass the scancode. */
-      int scanPC = keysym->scancode;
       if (offset == -1)
       {
         offset = Keymap_FindScanCodeOffset(keysym);
@@ -482,14 +481,15 @@ static char Keymap_PcToStScanCode(SDL_keysym* keysym)
       if (offset >= 0)
       {
         /* offset is defined so pass the scancode directly */
-        return (scanPC - offset);
+        return (keysym->scancode - offset);
       }
       else
       {
-        fprintf(stderr, "Unknown key: scancode = %d ($%02x), keycode = '%s' ($%02x)\n",
-                scanPC, scanPC, SDL_GetKeyName(keysym->sym), keysym->sym);
-	fprintf(stderr,"trying offset 8 (the most likely !)\n");
-        return (scanPC - 8);
+        /* Failed to detect offset, so use default value 8 */
+        fprintf(stderr, "Offset detection failed with "
+                "key '%s', scancode = 0x%02x, symcode =  0x%02x\n",
+                SDL_GetKeyName(keysym->sym), keysym->scancode, keysym->sym);
+        return (keysym->scancode - 8);
       }
     }
   }
@@ -718,22 +718,22 @@ void Keymap_KeyDown(SDL_keysym *sdlkey)
 
   /*fprintf(stderr, "keydown: sym=%i scan=%i mod=$%x\n",symkey, sdlkey->scancode, modkey);*/
 
-  /* If using cursor emulation, DON'T send keys to keyboard processor!!! Some games use keyboard as pause! */
-  if((ConfigureParams.Joysticks.Joy[0].bCursorEmulation || ConfigureParams.Joysticks.Joy[1].bCursorEmulation)
-     && !(modkey & KMOD_SHIFT))
+  /* If pressed short-cut key, retain keypress until safe to execute (start of VBL) */
+  if ((modkey & KEYMAP_SHORTCUTMODS) || symkey == SDLK_F11 || symkey == SDLK_F12)
   {
-    if(symkey == SDLK_UP)
-      { cursorJoyEmu |= 1; return; }
-    else if(symkey == SDLK_DOWN)
-      { cursorJoyEmu |= 2; return; }
-    else if(symkey == SDLK_LEFT)
-      { cursorJoyEmu |= 4; return; }
-    else if(symkey == SDLK_RIGHT)
-      { cursorJoyEmu |= 8; return; }
-    else if(symkey == SDLK_RCTRL || symkey == SDLK_KP0 || symkey == SDLK_LMETA)
-      { cursorJoyEmu |= 128; return; }
+    ShortCutKey.Key = symkey;
+    if (modkey & KMOD_CTRL)
+      ShortCutKey.bCtrlPressed = TRUE;
+    if (modkey & KMOD_SHIFT)
+      ShortCutKey.bShiftPressed = TRUE;
+    return;
   }
 
+  /* If using joystick emulation via keyboard, DON'T send keys to keyboard processor!!!
+   * Some games use keyboard as pause! */
+  if (Joy_KeyDown(symkey, modkey))
+    return;
+
   /* Handle special keys */
   if (symkey == SDLK_RALT || symkey == SDLK_LMETA || symkey == SDLK_RMETA
       || symkey == SDLK_MODE || symkey == SDLK_NUMLOCK)
@@ -748,31 +748,16 @@ void Keymap_KeyDown(SDL_keysym *sdlkey)
     DebugUI();
     return;
   }
-  else if(symkey == SDLK_F11 || symkey == SDLK_F12)
-  {
-    ShortCutKey.Key = symkey;
-    return;
-  }
 
   /* Set down */
   bPreviousKeyState = Keyboard.KeyStates[symkey];
   Keyboard.KeyStates[symkey] = TRUE;
 
-  /* If pressed short-cut key, retain keypress until safe to execute (start of VBL) */
-  if (modkey & KEYMAP_SHORTCUTMODS)
+  STScanCode = Keymap_RemapKeyToSTScanCode(sdlkey);
+  if (STScanCode != (char)-1)
   {
-    ShortCutKey.Key = symkey;
-    if (modkey & KMOD_CTRL)  ShortCutKey.bCtrlPressed = TRUE;
-    if (modkey & KMOD_SHIFT)  ShortCutKey.bShiftPressed = TRUE;
-  }
-  else
-  {
-    STScanCode = Keymap_RemapKeyToSTScanCode(sdlkey);
-    if(STScanCode != (char)-1)
-    {
-      if(!bPreviousKeyState)
-        IKBD_PressSTKey(STScanCode, TRUE);
-    }
+    if (!bPreviousKeyState)
+      IKBD_PressSTKey(STScanCode, TRUE);
   }
 }
 
@@ -789,22 +774,17 @@ void Keymap_KeyUp(SDL_keysym *sdlkey)
 
   /*fprintf(stderr, "keyup: sym=%i scan=%i mod=$%x\n",symkey, sdlkey->scancode, modkey);*/
 
-  /* If using cursor emulation, DON'T send keys to keyboard processor!!! Some games use keyboard as pause! */
-  if((ConfigureParams.Joysticks.Joy[0].bCursorEmulation || ConfigureParams.Joysticks.Joy[1].bCursorEmulation)
-     && !(modkey & KMOD_SHIFT))
+  /* Ignore short-cut keys here */
+  if ((modkey & KEYMAP_SHORTCUTMODS) || symkey == SDLK_F11 || symkey == SDLK_F12)
   {
-    if(symkey == SDLK_UP)
-      { cursorJoyEmu &= ~1; return; }
-    else if(symkey == SDLK_DOWN)
-      { cursorJoyEmu &= ~2; return; }
-    else if(symkey == SDLK_LEFT)
-      { cursorJoyEmu &= ~4; return; }
-    else if(symkey == SDLK_RIGHT)
-      { cursorJoyEmu &= ~8; return; }
-    else if(symkey == SDLK_RCTRL || symkey == SDLK_KP0 || symkey == SDLK_LMETA)
-      { cursorJoyEmu &= ~128; return; }
+    return;
   }
 
+  /* If using keyboard emulation, DON'T send keys to keyboard processor!!!
+   * Some games use keyboard as pause! */
+  if (Joy_KeyUp(symkey, modkey))
+    return;
+
   /* Handle special keys */
   if (symkey == SDLK_RALT || symkey == SDLK_LMETA || symkey == SDLK_RMETA
       || symkey == SDLK_MODE || symkey == SDLK_NUMLOCK)
@@ -817,10 +797,6 @@ void Keymap_KeyUp(SDL_keysym *sdlkey)
     /* Simulate another capslock key press */
     IKBD_PressSTKey(0x3A, TRUE);
   }
-  else if(symkey == SDLK_F11 || symkey == SDLK_F12)
-  {
-    return;
-  }
 
   /* Release key (only if was pressed) */
   if(Keyboard.KeyStates[symkey])
