@@ -8,11 +8,10 @@
   few OpCode's such as Line-F and Line-A. In Hatari it has mainly become a
   wrapper between the WinSTon sources and the UAE CPU code.
 */
-char M68000_rcsid[] = "Hatari $Id: m68000.c,v 1.28 2004/06/11 10:04:46 thothy Exp $";
+char M68000_rcsid[] = "Hatari $Id: m68000.c,v 1.33 2005/07/15 19:30:32 thothy Exp $";
 
 #include "main.h"
 #include "bios.h"
-#include "debug.h"
 #include "gemdos.h"
 #include "hatari-glue.h"
 #include "int.h"
@@ -28,9 +27,10 @@ char M68000_rcsid[] = "Hatari $Id: m68000.c,v 1.28 2004/06/11 10:04:46 thothy Ex
 void *PendingInterruptFunction;
 short int PendingInterruptCount;
 
-Uint32 BusAddressLocation;       /* Stores the offending address for bus-/address errors */
+Uint32 BusErrorAddress;          /* Stores the offending address for bus-/address errors */
 Uint32 BusErrorPC;               /* Value of the PC when bus error occurs */
 BOOL bBusErrorReadWrite;         /* 0 for write error, 1 for read error */
+int nCpuFreqShift;               /* Used to emulate higher CPU frequencies: 0=8MHz, 1=16MHz, 2=32Mhz */
 
 
 /*-----------------------------------------------------------------------*/
@@ -145,7 +145,7 @@ void M68000_MemorySnapShot_Capture(BOOL bSave)
   BUSERROR - Access outside valid memory range.
   Use bReadWrite = 0 for write errors and bReadWrite = 1 for read errors!
 */
-void M68000_BusError(unsigned long addr, BOOL bReadWrite)
+void M68000_BusError(Uint32 addr, BOOL bReadWrite)
 {
   /* FIXME: In prefetch mode, m68k_getpc() seems already to point to the next instruction */
   BusErrorPC = m68k_getpc();
@@ -156,24 +156,12 @@ void M68000_BusError(unsigned long addr, BOOL bReadWrite)
     fprintf(stderr, "M68000_BusError at address $%lx\n", (long)addr);
   }
 
-  BusAddressLocation = addr;        /* Store for exception frame */
+  BusErrorAddress = addr;         /* Store for exception frame */
   bBusErrorReadWrite = bReadWrite;
   set_special(SPCFLAG_BUSERROR);    /* The exception will be done in newcpu.c */
 }
 
 
-/*-----------------------------------------------------------------------*/
-/*
-  ADDRESSERROR - Access incorrect memory boundary, eg byte offset for a word access
-*/
-void M68000_AddressError(unsigned long addr)
-{
-  fprintf(stderr, "M68000_AddressError at address $%lx\n", (long)addr);
-  BusAddressLocation = addr;                /* Store for exception frame */
-  M68000_Exception(EXCEPTION_ADDRERROR);    /* Cause trap */
-}
-
-
 /*-----------------------------------------------------------------------*/
 /*
   Exception handler
@@ -213,7 +201,7 @@ void M68000_Exception(Uint32 ExceptionVector)
     else
 #endif
     {
-      unsigned long MFPBaseVector = (unsigned int)(MFP_VR&0xf0)<<2;
+      Uint32 MFPBaseVector = (unsigned int)(MFP_VR&0xf0)<<2;
       if ( (ExceptionVector>=MFPBaseVector) && (ExceptionVector<=(MFPBaseVector+0x34)) )
         SR = (SR&SR_CLEAR_IPL)|0x0600; /* MFP, level 6 */
     }
