@@ -16,21 +16,22 @@
   reduce redundancy and the function 'MemorySnapShot_Store' decides if it
   should save or restore the data.
 */
-char MemorySnapShot_rcsid[] = "Hatari $Id: memorySnapShot.c,v 1.9 2004/10/31 17:32:50 thothy Exp $";
+char MemorySnapShot_rcsid[] = "Hatari $Id: memorySnapShot.c,v 1.19 2005/10/12 09:06:47 thothy Exp $";
 
 #include <SDL_types.h>
 #include <errno.h>
 
 #include "main.h"
 #include "blitter.h"
-#include "debug.h"
-#include "dialog.h"
+#include "configuration.h"
+#include "dmaSnd.h"
 #include "fdc.h"
 #include "file.h"
 #include "floppy.h"
 #include "gemdos.h"
 #include "ikbd.h"
 #include "int.h"
+#include "log.h"
 #include "m68000.h"
 #include "memorySnapShot.h"
 #include "mfp.h"
@@ -41,11 +42,11 @@ char MemorySnapShot_rcsid[] = "Hatari $Id: memorySnapShot.c,v 1.9 2004/10/31 17:
 #include "video.h"
 
 
-#define VERSION_STRING      "0.50 "   /* Version number of compatible memory snapshots - Always 6 bytes (inc' NULL) */
+#define VERSION_STRING      "0.80 "   /* Version number of compatible memory snapshots - Always 6 bytes (inc' NULL) */
 #define VERSION_STRING_SIZE    6      /* Size of above (inc' NULL) */
 
 
-#define COMPRESS_MEMORYSNAPSHOT     /* Compress snapshots to reduce disc space used */
+#define COMPRESS_MEMORYSNAPSHOT       /* Compress snapshots to reduce disk space used */
 
 #ifdef COMPRESS_MEMORYSNAPSHOT
 
@@ -67,7 +68,7 @@ static BOOL bCaptureSave, bCaptureError;
 /*
   Open file.
 */
-static MSS_File MemorySnapShot_fopen(char *pszFileName, char *pszMode)
+static MSS_File MemorySnapShot_fopen(const char *pszFileName, const char *pszMode)
 {
 #ifdef COMPRESS_MEMORYSNAPSHOT
 	return gzopen(pszFileName, pszMode);
@@ -109,7 +110,7 @@ static int MemorySnapShot_fread(MSS_File fhndl, char *buf, int len)
 /*
   Write data to file.
 */
-static int MemorySnapShot_fwrite(MSS_File fhndl, char *buf, int len)
+static int MemorySnapShot_fwrite(MSS_File fhndl, const char *buf, int len)
 {
 #ifdef COMPRESS_MEMORYSNAPSHOT
 	return gzwrite(fhndl, buf, len);
@@ -124,9 +125,8 @@ static int MemorySnapShot_fwrite(MSS_File fhndl, char *buf, int len)
   Open/Create snapshot file, and set flag so 'MemorySnapShot_Store' knows
   how to handle data.
 */
-static BOOL MemorySnapShot_OpenFile(char *pszFileName, BOOL bSave)
+static BOOL MemorySnapShot_OpenFile(const char *pszFileName, BOOL bSave)
 {
-	char szString[256];
 	char VersionString[VERSION_STRING_SIZE];
 
 	/* Set error */
@@ -146,7 +146,8 @@ static BOOL MemorySnapShot_OpenFile(char *pszFileName, BOOL bSave)
 		}
 		bCaptureSave = TRUE;
 		/* Store version string */
-		MemorySnapShot_Store(VERSION_STRING, VERSION_STRING_SIZE);
+		strcpy(VersionString, VERSION_STRING);
+		MemorySnapShot_Store(VersionString, VERSION_STRING_SIZE);
 	}
 	else
 	{
@@ -166,9 +167,8 @@ static BOOL MemorySnapShot_OpenFile(char *pszFileName, BOOL bSave)
 		if (strcasecmp(VersionString, VERSION_STRING))
 		{
 			/* No, inform user and error */
-			sprintf(szString,"Unable to Restore Memory State.\n"
-			        "File is only compatible with Hatari v%s", VersionString);
-			Main_Message(szString, PROG_NAME /*, MB_OK | MB_ICONSTOP*/);
+			Log_AlertDlg(LOG_WARN, "Unable to Restore Memory State.\nFile is "
+			                       "only compatible with Hatari v%s", VersionString);
 			bCaptureError = TRUE;
 			return(FALSE);
 		}
@@ -217,7 +217,7 @@ void MemorySnapShot_Store(void *pData, int Size)
 /*
   Save 'snapshot' of memory/chips/emulation variables
 */
-void MemorySnapShot_Capture(char *pszFileName)
+void MemorySnapShot_Capture(const char *pszFileName)
 {
 	/* Set to 'saving' */
 	if (MemorySnapShot_OpenFile(pszFileName,TRUE))
@@ -236,6 +236,7 @@ void MemorySnapShot_Capture(char *pszFileName)
 		TOS_MemorySnapShot_Capture(TRUE);
 		Video_MemorySnapShot_Capture(TRUE);
 		Blitter_MemorySnapShot_Capture(TRUE);
+		DmaSnd_MemorySnapShot_Capture(TRUE);
 
 		/* And close */
 		MemorySnapShot_CloseFile();
@@ -243,9 +244,9 @@ void MemorySnapShot_Capture(char *pszFileName)
 
 	/* Did error */
 	if (bCaptureError)
-		Main_Message("Unable to Save Memory State to file.", PROG_NAME /*, MB_OK | MB_ICONSTOP*/);
+		Log_AlertDlg(LOG_ERROR, "Unable to save memory state to file.");
 	else
-		Main_Message("Memory State file saved.", PROG_NAME /*, MB_OK | MB_ICONINFORMATION*/);
+		Log_AlertDlg(LOG_INFO, "Memory state file saved.");
 }
 
 
@@ -253,7 +254,7 @@ void MemorySnapShot_Capture(char *pszFileName)
 /*
   Restore 'snapshot' of memory/chips/emulation variables
 */
-void MemorySnapShot_Restore(char *pszFileName)
+void MemorySnapShot_Restore(const char *pszFileName)
 {
 	/* Set to 'restore' */
 	if (MemorySnapShot_OpenFile(pszFileName,FALSE))
@@ -275,6 +276,7 @@ void MemorySnapShot_Restore(char *pszFileName)
 		TOS_MemorySnapShot_Capture(FALSE);
 		Video_MemorySnapShot_Capture(FALSE);
 		Blitter_MemorySnapShot_Capture(FALSE);
+		DmaSnd_MemorySnapShot_Capture(FALSE);
 
 		/* And close */
 		MemorySnapShot_CloseFile();
@@ -282,7 +284,7 @@ void MemorySnapShot_Restore(char *pszFileName)
 
 	/* Did error? */
 	if (bCaptureError)
-		Main_Message("Unable to Restore Memory State from file.", PROG_NAME /*,MB_OK | MB_ICONSTOP*/);
+		Log_AlertDlg(LOG_ERROR, "Unable to restore memory state from file.");
 	else
-		Main_Message("Memory State file restored.", PROG_NAME /*,MB_OK | MB_ICONINFORMATION*/);
+		Log_AlertDlg(LOG_INFO, "Memory state file restored.");
 }
