@@ -4,16 +4,15 @@
   This file is distributed under the GNU Public License, version 2 or at
   your option any later version. Read the file gpl.txt for details.
 
-  MSA Disc support
+  MSA Disk support
 */
-char MSA_rcsid[] = "Hatari $Id: msa.c,v 1.6 2004/04/28 09:04:58 thothy Exp $";
+char MSA_rcsid[] = "Hatari $Id: msa.c,v 1.9 2005/09/13 01:10:09 thothy Exp $";
 
 #include <SDL_endian.h>
 
 #include "main.h"
 #include "file.h"
 #include "floppy.h"
-#include "memAlloc.h"
 #include "misc.h"
 #include "msa.h"
 
@@ -150,11 +149,11 @@ Uint8 *MSA_UnCompress(Uint8 *pMSAFile, long *pImageSize)
     pImageBuffer = (unsigned char *)pBuffer;
     pMSAImageBuffer = (unsigned char *)((unsigned long)pMSAFile+sizeof(MSAHEADERSTRUCT));
 
-    /* Uncompress to memory as '.ST' disc image - NOTE: assumes 512 bytes per sector (use NUMBYTESPERSECTOR define)!!! */
+    /* Uncompress to memory as '.ST' disk image - NOTE: assumes 512 bytes per sector (use NUMBYTESPERSECTOR define)!!! */
     for(Track=pMSAHeader->StartingTrack; Track <= pMSAHeader->EndingTrack; Track++) {
       for(Side=0; Side<(pMSAHeader->Sides+1); Side++) {
         /* Uncompress MSA Track, first check if is not compressed */
-        DataLength = do_get_mem_word((uae_u16 *)pMSAImageBuffer);
+        DataLength = do_get_mem_word(pMSAImageBuffer);
         pMSAImageBuffer += sizeof(short int);
         if (DataLength==(NUMBYTESPERSECTOR*pMSAHeader->SectorsPerTrack)) {
           /* No compression on track, simply copy and continue */
@@ -173,11 +172,11 @@ Uint8 *MSA_UnCompress(Uint8 *pMSAFile, long *pImageSize)
             }
             else {
               Data = *pMSAImageBuffer++;                /* Byte to copy */
-              RunLength = do_get_mem_word((uae_u16 *)pMSAImageBuffer);  /* For length */
+              RunLength = do_get_mem_word(pMSAImageBuffer);  /* For length */
               /* Limit length to size of track, incorrect images may overflow */
               if ( (RunLength+NumBytesUnCompressed)>(NUMBYTESPERSECTOR*pMSAHeader->SectorsPerTrack) )
               {
-                fprintf(stderr, "MSA_UnCompress: Illegal run length -> corrupted disc image?\n");
+                fprintf(stderr, "MSA_UnCompress: Illegal run length -> corrupted disk image?\n");
                 RunLength = (NUMBYTESPERSECTOR*pMSAHeader->SectorsPerTrack)-NumBytesUnCompressed;
               }
               pMSAImageBuffer += sizeof(short int);
@@ -201,13 +200,13 @@ Uint8 *MSA_UnCompress(Uint8 *pMSAFile, long *pImageSize)
 
 /*-----------------------------------------------------------------------*/
 /*
-  Uncompress .MSA file into memory, set number bytes of the disc image and
+  Uncompress .MSA file into memory, set number bytes of the disk image and
   return a pointer to the buffer.
 */
-Uint8 *MSA_ReadDisc(char *pszFileName, long *pImageSize)
+Uint8 *MSA_ReadDisk(char *pszFileName, long *pImageSize)
 {
   Uint8 *pMsaFile;
-  Uint8 *pDiscBuffer = NULL;
+  Uint8 *pDiskBuffer = NULL;
 
   *pImageSize = 0;
 
@@ -215,15 +214,15 @@ Uint8 *MSA_ReadDisc(char *pszFileName, long *pImageSize)
   pMsaFile = File_Read(pszFileName, NULL, NULL, NULL);
   if (pMsaFile)
   {
-    /* Uncompress into disc buffer */
-    pDiscBuffer = MSA_UnCompress(pMsaFile, pImageSize);
+    /* Uncompress into disk buffer */
+    pDiskBuffer = MSA_UnCompress(pMsaFile, pImageSize);
 
     /* Free MSA file we loaded */
     free(pMsaFile);
   }
 
   /* Return pointer to buffer, NULL if failed */
-  return(pDiscBuffer);
+  return pDiskBuffer;
 }
 
 
@@ -274,7 +273,7 @@ static int MSA_FindRunOfBytes(unsigned char *pBuffer, int nBytesInBuffer)
 /*
   Save compressed .MSA file from memory buffer. Returns TRUE is all OK
 */
-BOOL MSA_WriteDisc(char *pszFileName,unsigned char *pBuffer,int ImageSize)
+BOOL MSA_WriteDisk(char *pszFileName, Uint8 *pBuffer, int ImageSize)
 {
 #ifdef SAVE_TO_MSA_IMAGES
 
@@ -287,12 +286,17 @@ BOOL MSA_WriteDisc(char *pszFileName,unsigned char *pBuffer,int ImageSize)
   int Track,Side;
 
   /* Allocate workspace for compressed image */
-  pMSAImageBuffer = (unsigned char *)Memory_Alloc(MSA_WORKSPACE_SIZE);
+  pMSAImageBuffer = (unsigned char *)malloc(MSA_WORKSPACE_SIZE);
+  if (!pMSAImageBuffer)
+  {
+    perror("MSA_WriteDisk");
+    return FALSE;
+  }
 
   /* Store header */
   pMSAHeader = (MSAHEADERSTRUCT *)pMSAImageBuffer;
   pMSAHeader->ID = SDL_SwapBE16(0x0E0F);
-  Floppy_FindDiscDetails(pBuffer,ImageSize,&nSectorsPerTrack,&nSides);
+  Floppy_FindDiskDetails(pBuffer,ImageSize,&nSectorsPerTrack,&nSides);
   pMSAHeader->SectorsPerTrack = SDL_SwapBE16(nSectorsPerTrack);
   pMSAHeader->Sides = SDL_SwapBE16(nSides-1);
   pMSAHeader->StartingTrack = SDL_SwapBE16(0);
@@ -326,7 +330,7 @@ BOOL MSA_WriteDisc(char *pszFileName,unsigned char *pBuffer,int ImageSize)
           /* Store run! */
           *pMSABuffer++ = 0xE5;               /* Marker */
           *pMSABuffer++ = *pImageBuffer;      /* Byte, and follow with 16-bit length */
-          do_put_mem_word((uae_u16 *)pMSABuffer, nBytesRun);
+          do_put_mem_word(pMSABuffer, nBytesRun);
           pMSABuffer += sizeof(short int);
           pImageBuffer += nBytesRun;
           nCompressedBytes += 4;
@@ -354,7 +358,7 @@ BOOL MSA_WriteDisc(char *pszFileName,unsigned char *pBuffer,int ImageSize)
   nRet = File_Save(pszFileName,pMSAImageBuffer,pMSABuffer-pMSAImageBuffer,FALSE);
 
   /* Free workspace */
-  Memory_Free(pMSAImageBuffer);
+  free(pMSAImageBuffer);
 
   return(nRet);
 
