@@ -13,7 +13,7 @@
   the bytes into an input buffer. This method fits in with the internet code
   which also reads data into a buffer.
 */
-char RS232_rcsid[] = "Hatari $Id: rs232.c,v 1.15 2004/08/03 21:18:37 thothy Exp $";
+char RS232_rcsid[] = "Hatari $Id: rs232.c,v 1.17 2005/09/26 15:20:14 thothy Exp $";
 
 #ifndef HAVE_TERMIOS_H
 #define HAVE_TERMIOS_H 1
@@ -30,7 +30,6 @@ char RS232_rcsid[] = "Hatari $Id: rs232.c,v 1.15 2004/08/03 21:18:37 thothy Exp
 
 #include "main.h"
 #include "configuration.h"
-#include "debug.h"
 #include "mfp.h"
 #include "stMemory.h"
 #include "rs232.h"
@@ -598,7 +597,7 @@ static void RS232_AddBytesToInputBuffer(unsigned char *pBytes, int nBytes)
 int RS232_ThreadFunc(void *pData)
 {
 	int iInChar;
-	char cInChar;
+	unsigned char cInChar;
 
 	/* Check for any RS-232 incoming data */
 	while (TRUE)
