@@ -6,25 +6,24 @@
 
   Screen Snapshots.
 */
-char ScreenSnapShot_rcsid[] = "Hatari $Id: screenSnapShot.c,v 1.7 2004/04/19 08:53:47 thothy Exp $";
+char ScreenSnapShot_rcsid[] = "Hatari $Id: screenSnapShot.c,v 1.9 2005/06/05 14:19:39 thothy Exp $";
 
 #include <SDL.h>
 #include <dirent.h>
 #include <string.h>
 
 #include "main.h"
-#include "memAlloc.h"
-#include "misc.h"
+#include "log.h"
 #include "screen.h"
 #include "screenSnapShot.h"
 #include "video.h"
-#include "vdi.h"
 
 
-int nScreenShots=0;                  /* Number of screen shots saved */
-BOOL bRecordingAnimation=FALSE;      /* Recording animation? */
-BOOL bGrabWhenChange;
-int GrabFrameCounter,GrabFrameLatch;
+BOOL bRecordingAnimation = FALSE;           /* Recording animation? */
+static int nScreenShots = 0;                /* Number of screen shots saved */
+static BOOL bGrabWhenChange;
+static int GrabFrameCounter,GrabFrameLatch;
+
 
 /*-----------------------------------------------------------------------*/
 /*
@@ -64,7 +63,9 @@ static void ScreenSnapShot_GetNum(void)
 */
 void ScreenSnapShot_SaveScreen(void)
 {
-  char *szFileName = Memory_Alloc(FILENAME_MAX);
+  char *szFileName = malloc(FILENAME_MAX);
+
+  if (!szFileName)  return;
 
   ScreenSnapShot_GetNum();
   /* Create our filename */
@@ -75,7 +76,7 @@ void ScreenSnapShot_SaveScreen(void)
   else 
     fprintf(stderr, "Screen dump saved to: %s\n", szFileName);    
 
-  Memory_Free(szFileName);
+  free(szFileName);
 }
 
 /*-----------------------------------------------------------------------*/
@@ -100,10 +101,9 @@ void ScreenSnapShot_BeginRecording(BOOL bCaptureChange, int nFramesPerSecond)
   GrabFrameLatch = (int)(50.0f/(float)nFramesPerSecond);
   /* Start animation */
   bRecordingAnimation = TRUE;
-  /* Set status bar */
-  /*StatusBar_SetIcon(STATUS_ICON_SCREEN,ICONSTATE_ON);*/ /* Sorry - Hatari does not has a statusbar yet */
+
   /* And inform user */
-  Main_Message("Screen-Shot recording started.",PROG_NAME /*,MB_OK|MB_ICONINFORMATION*/);
+  Log_AlertDlg(LOG_INFO, "Screenshot recording started.");
 }
 
 /*-----------------------------------------------------------------------*/
@@ -116,10 +116,9 @@ void ScreenSnapShot_EndRecording()
   if (bRecordingAnimation) {
     /* Stop animation */
     bRecordingAnimation = FALSE;
-    /* Turn off icon */
-    /*StatusBar_SetIcon(STATUS_ICON_SCREEN,ICONSTATE_OFF);*/ /* Sorry - no statusbar support yet */
+
     /* And inform user */
-    Main_Message("Screen-Shot recording stopped.",PROG_NAME /*,MB_OK|MB_ICONINFORMATION*/);
+    Log_AlertDlg(LOG_INFO, "Screenshot recording stopped.");
   }
 }
 
