@@ -6,7 +6,7 @@
 
   Shortcut keys
 */
-char ShortCut_rcsid[] = "Hatari $Id: shortcut.c,v 1.18 2004/06/24 14:52:57 thothy Exp $";
+char ShortCut_rcsid[] = "Hatari $Id: shortcut.c,v 1.21 2005/09/27 08:53:50 thothy Exp $";
 
 #include <SDL.h>
 
@@ -15,7 +15,6 @@ char ShortCut_rcsid[] = "Hatari $Id: shortcut.c,v 1.18 2004/06/24 14:52:57 thoth
 #include "audio.h"
 #include "joy.h"
 #include "m68000.h"
-#include "memAlloc.h"
 #include "memorySnapShot.h"
 #include "reset.h"
 #include "screen.h"
@@ -157,7 +156,7 @@ static void ShortCut_MaximumSpeed(void)
     ConfigureParams.System.nMinMaxSpeed = MINMAXSPEED_MIN;
     
     /* Reset the sound emulation variables: */
-    Sound_Reset();
+    Sound_ResetBufferIndex();
   }
   else
   {
@@ -214,7 +213,7 @@ static void ShortCut_WarmReset(void)
 static void ShortCut_ClearKeys(void)
 {
   /* Clear short-cut key structure */
-  Memory_Clear(&ShortCutKey,sizeof(SHORTCUT_KEY));
+  memset(&ShortCutKey, 0, sizeof(SHORTCUT_KEY));
 }
 
 
@@ -227,9 +226,11 @@ void ShortCut_CheckKeys(void)
   /* Check for supported keys: */
   switch(ShortCutKey.Key)
   {
+   case SDLK_f:
    case SDLK_F11:                  /* Switch between fullscreen/windowed mode */
     ShortCut_FullScreen();
     break;
+   case SDLK_o:
    case SDLK_F12:                  /* Show options dialog */
     Dialog_DoProperty();
     break;
