@@ -19,17 +19,16 @@
   sound and it simply doesn't work. If the emulator cannot keep the speed, users will have to turn off
   the sound - that's it.
 */
-char Sound_rcsid[] = "Hatari $Id: sound.c,v 1.15 2004/04/23 15:33:59 thothy Exp $";
+char Sound_rcsid[] = "Hatari $Id: sound.c,v 1.21 2005/09/27 08:53:50 thothy Exp $";
 
 #include <SDL_types.h>
 
 #include "main.h"
 #include "audio.h"
-#include "debug.h"
-#include "dialog.h"
+#include "dmaSnd.h"
 #include "file.h"
 #include "int.h"
-#include "memAlloc.h"
+#include "log.h"
 #include "memorySnapShot.h"
 #include "misc.h"
 #include "psg.h"
@@ -40,9 +39,9 @@ char Sound_rcsid[] = "Hatari $Id: sound.c,v 1.15 2004/04/23 15:33:59 thothy Exp
 
 #define LONGLONG Uint64
 
-#define ENVELOPE_PERIOD(Fine,Coarse)  (((unsigned long)Coarse)<<8) + (unsigned long)Fine
-#define NOISE_PERIOD(Freq)            ((((unsigned long)Freq)&0x1f)<<11)
-#define TONE_PERIOD(Fine,Coarse)      ((((unsigned long)Coarse)&0x0f)<<8) + (unsigned long)Fine
+#define ENVELOPE_PERIOD(Fine,Coarse)  ((((Uint32)Coarse)<<8) + (Uint32)Fine)
+#define NOISE_PERIOD(Freq)            (((((Uint32)Freq)&0x1f)<<11))
+#define TONE_PERIOD(Fine,Coarse)      (((((Uint32)Coarse)&0x0f)<<8) + (Uint32)Fine)
 #define MIXTABLE_SIZE    (256*8)        /* Large table, so don't overflow */
 #define TONEFREQ_SHIFT   28             /* 4.28 fixed point */
 #define NOISEFREQ_SHIFT  28             /* 4.28 fixed point */
@@ -59,14 +58,14 @@ char Sound_rcsid[] = "Hatari $Id: sound.c,v 1.15 2004/04/23 15:33:59 thothy Exp
 /* Original wave samples */
 static int EnvelopeShapeValues[16*1024];                        /* Shape x Length(repeat 3rd/4th entries) */
 /* Frequency and time period samples */
-static unsigned long ChannelFreq[3], EnvelopeFreq, NoiseFreq;   /* Current frequency of each channel A,B,C,Envelope and Noise */
+static Uint32 ChannelFreq[3], EnvelopeFreq, NoiseFreq;          /* Current frequency of each channel A,B,C,Envelope and Noise */
 static int ChannelAmpDecayTime[3];                              /* Store counter to show if amplitude is changed to generate 'samples' */
 static int Envelope[SAMPLES_BUFFER_SIZE],Noise[SAMPLES_BUFFER_SIZE];   /* Current sample for this time period */
 /* Output channel data */
 static int Channel_A_Buffer[SAMPLES_BUFFER_SIZE],Channel_B_Buffer[SAMPLES_BUFFER_SIZE],Channel_C_Buffer[SAMPLES_BUFFER_SIZE];
-/* Use table to convert from (A+B+C) to clipped 'unsigned char' for sound buffer */
-static char MixTable[MIXTABLE_SIZE];                            /* -ve and +ve range */
-static char *pMixTable = &MixTable[MIXTABLE_SIZE/2];            /* Signed index into above */
+/* Use table to convert from (A+B+C) to clipped 8-bit for sound buffer */
+static Sint8 MixTable[MIXTABLE_SIZE];                           /* -ve and +ve range */
+static Sint8 *pMixTable = &MixTable[MIXTABLE_SIZE/2];           /* Signed index into above */
 static int ActiveSndBufIdx;                                     /* Current working index into above mix buffer */
 static int nSamplesToGenerate;                                  /* How many samples are needed for this time-frame */
 
@@ -75,7 +74,7 @@ BOOL bWriteEnvelopeFreq;                                        /* Did write to
 BOOL bWriteChannelAAmp, bWriteChannelBAmp, bWriteChannelCAmp;   /* Did write to amplitude registers? */
 BOOL bEnvelopeFreqFlag;                                         /* As above, but cleared each frame for YM saving */
 /* Buffer to store circular samples */
-char MixBuffer[MIXBUFFER_SIZE];
+Sint8 MixBuffer[MIXBUFFER_SIZE];
 int nGeneratedSamples;                                          /* Generated samples since audio buffer update */
 int SoundCycles;
 
@@ -223,7 +222,12 @@ void Sound_Reset(void)
 {
   int i;
 
-  Sound_ClearMixBuffer();       /* Clear buffer */
+  /* Lock audio system before accessing variables which are used by the
+   * callback function, too! */
+  Audio_Lock();
+
+  /* Clear sound mixing buffer: */
+  memset(MixBuffer, 0, MIXBUFFER_SIZE);
 
   /* Clear cycle counts, buffer index and register '13' flags */
   SoundCycles = 0;
@@ -231,12 +235,9 @@ void Sound_Reset(void)
   bWriteEnvelopeFreq = FALSE;
   bWriteChannelAAmp = bWriteChannelBAmp = bWriteChannelCAmp = FALSE;
 
-  /* Lock audio system before accessing variables that are also use by the callback function! */
-  Audio_Lock();
   CompleteSndBufIdx = 0;
   ActiveSndBufIdx =  (SoundBufferSize + SAMPLES_PER_FRAME) % MIXBUFFER_SIZE;
   nGeneratedSamples = 0;
-  Audio_Unlock();
 
   /* Clear frequency counter */
   for(i=0; i<3; i++)
@@ -245,19 +246,20 @@ void Sound_Reset(void)
     ChannelAmpDecayTime[i] = 0;
   }
   EnvelopeFreq = NoiseFreq = 0;
+
+  Audio_Unlock();
 }
 
 
 /*-----------------------------------------------------------------------*/
 /*
-  Clear mixer buffer, where samples are stored ready to pass to sound player
+  Reset the sound buffer index variables.
 */
-void Sound_ClearMixBuffer(void)
+void Sound_ResetBufferIndex(void)
 {
   Audio_Lock();
-
-  Memory_Clear(MixBuffer, MIXBUFFER_SIZE);      /* Clear buffer */
-
+  ActiveSndBufIdx =  (CompleteSndBufIdx + SoundBufferSize + SAMPLES_PER_FRAME)
+                     % MIXBUFFER_SIZE;
   Audio_Unlock();
 }
 
@@ -278,7 +280,8 @@ void Sound_MemorySnapShot_Capture(BOOL bSave)
 /*-----------------------------------------------------------------------*/
 /*
   Find how many samples to generate and store in 'nSamplesToGenerate'
-  Also update 'SoundCycles' to store how many we actually did so generates set amount each frame
+  Also update 'SoundCycles' to store how many we actually did so generates set
+  amount each frame.
 */
 static void Sound_SetSamplesPassed(void)
 {
@@ -336,14 +339,14 @@ static void Sound_SetSamplesPassed(void)
 static void Sound_GenerateEnvelope(unsigned char EnvShape, unsigned char Fine, unsigned char Coarse)
 {
   int *pEnvelopeValues;
-  unsigned long EnvelopePeriod,EnvelopeFreqDelta;
+  Uint32 EnvelopePeriod, EnvelopeFreqDelta;
   int i;
 
   /* Find envelope details */
   if (bWriteEnvelopeFreq)
     EnvelopeFreq = 0;
   pEnvelopeValues = &EnvelopeShapeValues[ (EnvShape&0x0f)*1024 ];          /* Envelope shape values */
-  EnvelopePeriod = ENVELOPE_PERIOD((unsigned long)Fine,(unsigned long)Coarse);
+  EnvelopePeriod = ENVELOPE_PERIOD((Uint32)Fine, (Uint32)Coarse);
 
   if (EnvelopePeriod==0)                                                   /* Handle div by zero */
     EnvelopeFreqDelta = 0;
@@ -368,10 +371,10 @@ static void Sound_GenerateEnvelope(unsigned char EnvShape, unsigned char Fine, u
 static void Sound_GenerateNoise(unsigned char MixerControl, unsigned char NoiseGen)
 {
   int NoiseValue;
-  unsigned long NoisePeriod,NoiseFreqDelta;
+  Uint32 NoisePeriod, NoiseFreqDelta;
   int i;
 
-  NoisePeriod = NOISE_PERIOD((unsigned long)NoiseGen);
+  NoisePeriod = NOISE_PERIOD((Uint32)NoiseGen);
 
   if (NoisePeriod==0)                                            /* Handle div by zero */
     NoiseFreqDelta = 0;
@@ -395,16 +398,16 @@ static void Sound_GenerateNoise(unsigned char MixerControl, unsigned char NoiseG
 /*
   Generate channel of samples for this time-frame
 */
-static void Sound_GenerateChannel(int *pBuffer, unsigned char ToneFine, unsigned char ToneCoarse,unsigned char Amplitude,unsigned char MixerControl,unsigned long *pChannelFreq,int MixMask)
+static void Sound_GenerateChannel(int *pBuffer, unsigned char ToneFine, unsigned char ToneCoarse, unsigned char Amplitude, unsigned char MixerControl, Uint32 *pChannelFreq, int MixMask)
 {   
   int *pNoise = Noise, *pEnvelope = Envelope;
-  unsigned long ToneFreq=*pChannelFreq;
-  unsigned long TonePeriod;
-  unsigned long ToneFreqDelta;
+  Uint32 ToneFreq = *pChannelFreq;
+  Uint32 TonePeriod;
+  Uint32 ToneFreqDelta;
   int i,Amp,Mix;
   int ToneOutput,NoiseOutput,MixerOutput,EnvelopeOutput,AmplitudeOutput;
 
-  TonePeriod = TONE_PERIOD((unsigned long)ToneFine,(unsigned long)ToneCoarse);
+  TonePeriod = TONE_PERIOD((Uint32)ToneFine, (Uint32)ToneCoarse);
   /* Find frequency of channel */
   if (TonePeriod==0)
     ToneFreqDelta = 0;                                  /* Handle div by zero */
@@ -493,10 +496,12 @@ static void Sound_GenerateSamples(void)
     Sound_GenerateChannel(pChannelB,PSGRegisters[PSG_REG_CHANNEL_B_FINE],PSGRegisters[PSG_REG_CHANNEL_B_COARSE],PSGRegisters[PSG_REG_CHANNEL_B_AMP],PSGRegisters[PSG_REG_MIXER_CONTROL],&ChannelFreq[1],1);
     Sound_GenerateChannel(pChannelC,PSGRegisters[PSG_REG_CHANNEL_C_FINE],PSGRegisters[PSG_REG_CHANNEL_C_COARSE],PSGRegisters[PSG_REG_CHANNEL_C_AMP],PSGRegisters[PSG_REG_MIXER_CONTROL],&ChannelFreq[2],2);
 
-    /* Mix channels together, using table to clip and also convert to 'unsigned char' */
+    /* Mix channels together, using table to clip and convert to proper 8-bit type */
     for(i=0; i<nSamplesToGenerate; i++)
       MixBuffer[(i+ActiveSndBufIdx)%MIXBUFFER_SIZE] = pMixTable[(*pChannelA++) + (*pChannelB++) + (*pChannelC++)];
 
+    DmaSnd_GenerateSamples(ActiveSndBufIdx, nSamplesToGenerate);
+
     ActiveSndBufIdx = (ActiveSndBufIdx + nSamplesToGenerate) % MIXBUFFER_SIZE;
     nGeneratedSamples += nSamplesToGenerate;
 
@@ -573,7 +578,7 @@ BOOL Sound_BeginRecording(char *pszCaptureFileName)
 
   if (!pszCaptureFileName || strlen(pszCaptureFileName) <= 3)
   {
-    fprintf(stderr, "Illegal sound recording file name!\n");
+    Log_Printf(LOG_ERROR, "Illegal sound recording file name!\n");
     return FALSE;
   }
 
@@ -584,11 +589,12 @@ BOOL Sound_BeginRecording(char *pszCaptureFileName)
     bRet = WAVFormat_OpenFile(pszCaptureFileName);
   else
   {
-    Main_Message("Unknown Sound Recording format\n\n.Please specify a .YM or .WAV output file.",PROG_NAME /*,MB_OK|MB_ICONSTOP*/);
+    Log_AlertDlg(LOG_ERROR, "Unknown Sound Recording format.\n"
+                            "Please specify a .YM or .WAV output file.");
     bRet = FALSE;
   }
 
-  return(bRet);
+  return bRet;
 }
 
 
