@@ -11,13 +11,12 @@
   We need to intercept the initial Line-A call (which we force into the TOS on
   boot-up) and also the init calls to the VDI.
 */
-char VDI_rcsid[] = "Hatari $Id: vdi.c,v 1.11 2004/04/23 15:33:59 thothy Exp $";
+char VDI_rcsid[] = "Hatari $Id: vdi.c,v 1.14 2005/07/15 19:30:32 thothy Exp $";
 
 #include "main.h"
 #include "file.h"
 #include "gemdos.h"
 #include "m68000.h"
-#include "memAlloc.h"
 #include "screen.h"
 #include "stMemory.h"
 #include "vdi.h"
@@ -26,19 +25,19 @@ char VDI_rcsid[] = "Hatari $Id: vdi.c,v 1.11 2004/04/23 15:33:59 thothy Exp $";
 
 
 BOOL bUseVDIRes=FALSE;             /* Set to TRUE (if want VDI), or FALSE (ie for games) */
-int LineABase;                     /* Line-A structure */
-int FontBase;                      /* Font base, used for 16-pixel high font */
-unsigned int VDI_OldPC;            /* When call Trap#2, store off PC */
+Uint32 LineABase;                  /* Line-A structure */
+Uint32 FontBase;                   /* Font base, used for 16-pixel high font */
+Uint32 VDI_OldPC;                  /* When call Trap#2, store off PC */
 
 int VDIWidth=640,VDIHeight=480;    /* 640x480,800x600 or 1024x768 */
 int VDIRes=0;                      /* 0,1 or 2(low, medium, high) */
 int VDIPlanes=4,VDIColours=16,VDICharHeight=8;  /* To match VDIRes */
 
-unsigned long Control;
-unsigned long Intin;
-unsigned long Ptsin;
-unsigned long Intout;
-unsigned long Ptsout;
+Uint32 Control;
+Uint32 Intin;
+Uint32 Ptsin;
+Uint32 Intout;
+Uint32 Ptsout;
 
 
 /*-----------------------------------------------------------------------*/
@@ -139,9 +138,7 @@ void VDI_SetResolution(int GEMRes,int GEMColour)
       break;
   }
 
-  /* Force screen code to re-set bitmap/full-screen */
-  Screen_SetDrawModes();
-  /*Screen_SetupRGBTable();*/
+  /* Force screen code to re-set the screen */
   Screen_SetFullUpdate();
   PrevSTRes = -1;
 
@@ -159,7 +156,7 @@ void VDI_SetResolution(int GEMRes,int GEMColour)
 */
 BOOL VDI(void)
 {
-  unsigned long TablePtr = Regs[REG_D1];
+  Uint32 TablePtr = Regs[REG_D1];
   /*unsigned short int OpCode;*/
 
   /* Read off table pointers */
@@ -275,7 +272,7 @@ done_modify:;
     /* And save */
     File_Save(pszFileName, pInfData, InfSize, FALSE);
     /* Free */
-    Memory_Free(pInfData);
+    free(pInfData);
   }
 }
 
@@ -295,7 +292,12 @@ void VDI_FixDesktopInf(void)
     return;
   }
 
-  szDesktopFileName = Memory_Alloc(2 * FILENAME_MAX);
+  szDesktopFileName = malloc(2 * FILENAME_MAX);
+  if (!szDesktopFileName)
+  {
+    perror("VDI_FixDesktopInf");
+    return;
+  }
   szNewDeskFileName = szDesktopFileName + FILENAME_MAX;
 
   /* Create filenames for hard-drive */
@@ -311,5 +313,5 @@ void VDI_FixDesktopInf(void)
     VDI_SaveDesktopInf(szNewDeskFileName,NewDeskScript,sizeof(NewDeskScript));
   VDI_ModifyDesktopInf(szNewDeskFileName);
 
-  Memory_Free(szDesktopFileName);
+  free(szDesktopFileName);
 }
