@@ -9,12 +9,12 @@
   We intercept and direct some XBios calls to handle the RS-232 etc. and help
   with floppy debugging.
 */
-char XBios_rcsid[] = "Hatari $Id: xbios.c,v 1.7 2004/07/25 13:50:30 thothy Exp $";
+char XBios_rcsid[] = "Hatari $Id: xbios.c,v 1.9 2005/07/15 19:30:32 thothy Exp $";
 
 #include "main.h"
 #include "configuration.h"
-#include "debug.h"
 #include "floppy.h"
+#include "log.h"
 #include "m68000.h"
 #include "misc.h"
 #include "rs232.h"
@@ -23,6 +23,9 @@ char XBios_rcsid[] = "Hatari $Id: xbios.c,v 1.7 2004/07/25 13:50:30 thothy Exp $
 #include "xbios.h"
 
 
+#define XBIOS_DEBUG 0
+
+
 /* List of Atari ST RS-232 baud rates */
 static int BaudRates[] = {
   19200, /* 0 */
@@ -49,11 +52,11 @@ static int BaudRates[] = {
   XBIOS Floppy Read
   Call 8
 */
-static BOOL XBios_Floprd(unsigned long Params)
+static BOOL XBios_Floprd(Uint32 Params)
 {
-#ifdef DEBUG_TO_FILE
+#if XBIOS_DEBUG
   char *pBuffer;
-  unsigned short int Dev,Sector,Side,Track,Count;
+  Uint16 Dev,Sector,Side,Track,Count;
 
   /* Read details from stack */
   pBuffer = (char *)STRAM_ADDR(STMemory_ReadLong(Params+SIZE_WORD));
@@ -63,7 +66,8 @@ static BOOL XBios_Floprd(unsigned long Params)
   Side = STMemory_ReadWord(Params+SIZE_WORD+SIZE_LONG+SIZE_LONG+SIZE_WORD+SIZE_WORD+SIZE_WORD);
   Count = STMemory_ReadWord(Params+SIZE_WORD+SIZE_LONG+SIZE_LONG+SIZE_WORD+SIZE_WORD+SIZE_WORD+SIZE_WORD);
 
-  Debug_FDC("FLOPRD %s,%d,%d,%d,%d at addr 0x%X\n",EmulationDrives[Dev].szFileName,Side,Track,Sector,Count,PC);
+  Log_Printf(LOG_DEBUG, "FLOPRD %s,%d,%d,%d,%d at addr 0x%X\n", EmulationDrives[Dev].szFileName,
+             Side, Track, Sector, Count, m68k_getpc());
 #endif
 
   return(FALSE);
@@ -75,11 +79,11 @@ static BOOL XBios_Floprd(unsigned long Params)
   XBIOS Floppy Write
   Call 9
 */
-static BOOL XBios_Flopwr(unsigned long Params)
+static BOOL XBios_Flopwr(Uint32 Params)
 {
-#ifdef DEBUG_TO_FILE
+#if XBIOS_DEBUG
   char *pBuffer;
-  unsigned short int Dev,Sector,Side,Track,Count;
+  Uint16 Dev,Sector,Side,Track,Count;
 
   /* Read details from stack */
   pBuffer = (char *)STRAM_ADDR(STMemory_ReadLong(Params+SIZE_WORD));
@@ -89,7 +93,8 @@ static BOOL XBios_Flopwr(unsigned long Params)
   Side = STMemory_ReadWord(Params+SIZE_WORD+SIZE_LONG+SIZE_LONG+SIZE_WORD+SIZE_WORD+SIZE_WORD);
   Count = STMemory_ReadWord(Params+SIZE_WORD+SIZE_LONG+SIZE_LONG+SIZE_WORD+SIZE_WORD+SIZE_WORD+SIZE_WORD);
 
-  Debug_FDC("FLOPWR %s,%d,%d,%d,%d at addr 0x%X\n",EmulationDrives[Dev].szFileName,Side,Track,Sector,Count,PC);
+  Log_Printf(LOG_DEBUG, "FLOPWR %s,%d,%d,%d,%d at addr 0x%X\n", EmulationDrives[Dev].szFileName,
+             Side, Track, Sector, Count, m68k_getpc());
 #endif
 
   return(FALSE);
@@ -101,7 +106,7 @@ static BOOL XBios_Flopwr(unsigned long Params)
   XBIOS RsConf
   Call 15
 */
-static BOOL XBios_Rsconf(unsigned long Params)
+static BOOL XBios_Rsconf(Uint32 Params)
 {
   short int Baud,Ctrl,Ucr,Rsr,Tsr,Scr;
 
@@ -145,7 +150,7 @@ static BOOL XBios_Rsconf(unsigned long Params)
   XBIOS Scrdmp
   Call 20
 */
-static BOOL XBios_Scrdmp(unsigned long Params)
+static BOOL XBios_Scrdmp(Uint32 Params)
 {
   fprintf(stderr, "XBIOS screendump!\n");
 
@@ -163,7 +168,7 @@ static BOOL XBios_Scrdmp(unsigned long Params)
   XBIOS Prtblk
   Call 36
 */
-static BOOL XBios_Prtblk(unsigned long Params)
+static BOOL XBios_Prtblk(Uint32 Params)
 {
   fprintf(stderr, "Intercepted XBIOS Prtblk()\n");
 
@@ -180,14 +185,14 @@ static BOOL XBios_Prtblk(unsigned long Params)
 */
 BOOL XBios(void)
 {
-  unsigned long Params;
-  unsigned short int XBiosCall;
+  Uint32 Params;
+  Uint16 XBiosCall;
 
   /* Find call */
   Params = Regs[REG_A7];
   XBiosCall = STMemory_ReadWord(Params);
 
-  /*Debug_File("XBIOS %d\n",XBiosCall);*/
+  /*Log_Printf(LOG_DEBUG, "XBIOS %d\n",XBiosCall);*/
 
   switch(XBiosCall)
   {
