@@ -4,9 +4,9 @@
   This file is distributed under the GNU Public License, version 2 or at
   your option any later version. Read the file gpl.txt for details.
 
-  Zipped disc support, uses zlib
+  Zipped disk support, uses zlib
 */
-char ZIP_rcsid[] = "Hatari $Id: zip.c,v 1.9 2004/05/03 15:34:50 thothy Exp $";
+char ZIP_rcsid[] = "Hatari $Id: zip.c,v 1.13 2005/09/26 15:20:14 thothy Exp $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -18,10 +18,9 @@ char ZIP_rcsid[] = "Hatari $Id: zip.c,v 1.9 2004/05/03 15:34:50 thothy Exp $";
 
 #include "main.h"
 #include "dim.h"
-#include "errlog.h"
 #include "file.h"
 #include "floppy.h"
-#include "memAlloc.h"
+#include "log.h"
 #include "msa.h"
 #include "st.h"
 #include "unzip.h"
@@ -84,49 +83,70 @@ zip_dir *ZIP_GetFiles(char *pszFileName)
   if (uf==NULL)
     {
       printf("Cannot open %s\n", pszFileName);
-      return(0);
+      return NULL;
     }
 
   err = unzGetGlobalInfo (uf,&gi);
   if (err!=UNZ_OK){
     printf("error %d with zipfile in unzGetGlobalInfo \n",err);
-    return(NULL);
+    return NULL;
   }
   
   /* allocate a file list */
-  filelist = (char **)Memory_Alloc(gi.number_entry*sizeof(char *));
+  filelist = (char **)malloc(gi.number_entry*sizeof(char *));
+  if (!filelist)
+  {
+    perror("ZIP_GetFiles");
+    return NULL;
+  }
+
   nfiles = gi.number_entry;  /* set the number of files */
   
   for(i=0;i<gi.number_entry;i++)
     {
       err = unzGetCurrentFileInfo(uf,&file_info,filename_inzip, ZIP_PATH_MAX,NULL,0,NULL,0);
       if (err!=UNZ_OK)
-	{
-	  Memory_Free(filelist);
-	  return(NULL);
-	}
-      filelist[i] = (char *)Memory_Alloc(strlen(filename_inzip) + 1);
+      {
+        free(filelist);
+        return NULL;
+      }
+
+      filelist[i] = (char *)malloc(strlen(filename_inzip) + 1);
+      if (!filelist[i])
+      {
+        perror("ZIP_GetFiles");
+        free(filelist);
+        return NULL;
+      }
+
       strcpy(filelist[i], filename_inzip);
       if ((i+1)<gi.number_entry)
-	{
-	  err = unzGoToNextFile(uf);
-	  if (err!=UNZ_OK)
-	    {
-	      ErrLog_File("ERROR ZIP_GetFiles with zipfile\n");
-	      /* deallocate memory */
-	      for(;i>0;i--)Memory_Free(filelist[i]);
-	      Memory_Free(filelist);
-	      return(NULL);
-	    }
-	}
+      {
+        err = unzGoToNextFile(uf);
+        if (err!=UNZ_OK)
+        {
+          Log_Printf(LOG_ERROR, "ZIP_GetFiles: Error in ZIP-file\n");
+          /* deallocate memory */
+          for(;i>0;i--)  free(filelist[i]);
+          free(filelist);
+          return NULL;
+        }
+      }
     }
 
   unzClose(uf);
 
-  zd = (zip_dir *)Memory_Alloc(sizeof(zip_dir));
+  zd = (zip_dir *)malloc(sizeof(zip_dir));
+  if (!zd)
+  {
+    perror("ZIP_GetFiles");
+    free(filelist);
+    return NULL;
+  }
   zd->names = filelist;
   zd->nfiles = nfiles;
-  return( zd );
+
+  return zd;
 }
 
 
@@ -139,12 +159,12 @@ void ZIP_FreeZipDir(zip_dir *f_zd)
   while (f_zd->nfiles > 0)
   {
     f_zd->nfiles--;
-    Memory_Free(f_zd->names[f_zd->nfiles]);
+    free(f_zd->names[f_zd->nfiles]);
     f_zd->names[f_zd->nfiles] = NULL;
   }
-  Memory_Free(f_zd->names);
+  free(f_zd->names);
   f_zd->names = NULL;
-  Memory_Free(f_zd);
+  free(f_zd);
 }
 
 
@@ -163,12 +183,26 @@ struct dirent **ZIP_GetFilesDir(zip_dir *zip, char *dir, int *entries)
   int slash;
   struct dirent **fentries;
 
-  files = (zip_dir *)Memory_Alloc(sizeof(zip_dir));
-  files->names = (char **)Memory_Alloc((zip->nfiles + 1) * sizeof(char *));
+  files = (zip_dir *)malloc(sizeof(zip_dir));
+  if (!files)
+  {
+    perror("ZIP_GetFilesDir");
+    return NULL;
+  }
+
+  files->names = (char **)malloc((zip->nfiles + 1) * sizeof(char *));
+  if (!files->names)
+  {
+    perror("ZIP_GetFilesDir");
+    free(files);
+    return NULL;
+  }
 
   /* add ".." directory */
   files->nfiles = 1;
-  temp = (char *)Memory_Alloc(4);
+  temp = (char *)malloc(4);
+  if (!temp)
+    return NULL;
   temp[0] = temp[1] = '.'; 
   temp[2] = '/'; temp[3] = '\0';
   files->names[0] = temp;
@@ -192,7 +226,12 @@ struct dirent **ZIP_GetFilesDir(zip_dir *zip, char *dir, int *entries)
 			    flag=TRUE;
 		      if( flag == FALSE )
 			{
-			  files->names[files->nfiles] = (char *)Memory_Alloc(slash+1);
+			  files->names[files->nfiles] = (char *)malloc(slash+1);
+			  if (!files->names[files->nfiles])
+			  {
+			    perror("ZIP_GetFilesDir");
+			    return NULL;
+			  }
 			  strncpy(files->names[files->nfiles], temp, slash+1);
 			  ((char *)files->names[files->nfiles])[slash+1] = '\0';
 			  files->nfiles++;
@@ -201,7 +240,12 @@ struct dirent **ZIP_GetFilesDir(zip_dir *zip, char *dir, int *entries)
 		  else 
 		    {
 		      /* add a filename */
-		      files->names[files->nfiles] = (char *)Memory_Alloc(strlen(temp)+1);
+		      files->names[files->nfiles] = (char *)malloc(strlen(temp)+1);
+		      if (!files->names[files->nfiles])
+		      {
+		        perror("ZIP_GetFilesDir");
+		        return NULL;
+		      }
 		      strncpy(files->names[files->nfiles], temp, strlen(temp));
 		      ((char *)files->names[files->nfiles])[strlen(temp)] = '\0';
 		      files->nfiles++;
@@ -213,21 +257,35 @@ struct dirent **ZIP_GetFilesDir(zip_dir *zip, char *dir, int *entries)
 
   /* copy to a dirent structure */
   *entries = files->nfiles;
-  fentries = (struct dirent **)Memory_Alloc(sizeof(struct dirent *)*files->nfiles);
+  fentries = (struct dirent **)malloc(sizeof(struct dirent *)*files->nfiles);
+  if (!fentries)
+  {
+    perror("ZIP_GetFilesDir");
+    ZIP_FreeZipDir(files);
+    return NULL;
+  }
   for(i=0; i<files->nfiles; i++)
     {
-      fentries[i] = (struct dirent *)Memory_Alloc(sizeof(struct dirent));
+      fentries[i] = (struct dirent *)malloc(sizeof(struct dirent));
+      if (!fentries[i])
+      {
+        perror("ZIP_GetFilesDir");
+        return NULL;
+      }
       strcpy(fentries[i]->d_name, files->names[i]);
     }
+
   ZIP_FreeZipDir(files);
+
   return(fentries);
 }
 
+
 /*-----------------------------------------------------------------------*/
 /*
   Check an image file in the archive, return the uncompressed length
 */
-static long ZIP_CheckImageFile(unzFile uf, char *filename, int *pDiscType)
+static long ZIP_CheckImageFile(unzFile uf, char *filename, int *pDiskType)
 {
   unz_file_info file_info;
 
@@ -246,19 +304,19 @@ static long ZIP_CheckImageFile(unzFile uf, char *filename, int *pDiscType)
   /* check for a .msa or .st extention */
   if(MSA_FileNameIsMSA(filename, FALSE))
     {
-      *pDiscType = ZIP_FILE_MSA;
+      *pDiskType = ZIP_FILE_MSA;
       return( file_info.uncompressed_size );
     }
 
   if(ST_FileNameIsST(filename, FALSE))
     {
-      *pDiscType = ZIP_FILE_ST;
+      *pDiskType = ZIP_FILE_ST;
       return( file_info.uncompressed_size );
     }
   
   if (DIM_FileNameIsDIM(filename, FALSE))
     {
-      *pDiscType = ZIP_FILE_DIM;
+      *pDiskType = ZIP_FILE_DIM;
       return( file_info.uncompressed_size );
     }
 
@@ -276,8 +334,15 @@ static char *ZIP_FirstFile(char *filename)
   int i;
   char *name;
 
-  if((files = ZIP_GetFiles(filename)) == NULL) return(NULL);
-  name = Memory_Alloc(ZIP_PATH_MAX);
+  if ((files = ZIP_GetFiles(filename)) == NULL)
+    return(NULL);
+
+  name = malloc(ZIP_PATH_MAX);
+  if (!name)
+  {
+    perror("ZIP_FirstFile");
+    return NULL;
+  }
 
   name[0] = '\0';
   for(i=files->nfiles-1;i>=0;i--)
@@ -303,7 +368,7 @@ static char *ZIP_FirstFile(char *filename)
   bytes to uncompress is size. Returns a pointer to a buffer containing
   the uncompressed data, or NULL.
 */
-static char *ZIP_ExtractFile(unzFile uf, char *filename, uLong size)
+static void *ZIP_ExtractFile(unzFile uf, char *filename, uLong size)
 {
   int err = UNZ_OK;
   char filename_inzip[ZIP_PATH_MAX];
@@ -314,8 +379,7 @@ static char *ZIP_ExtractFile(unzFile uf, char *filename, uLong size)
 
   if (unzLocateFile(uf,filename, 0)!=UNZ_OK)
     {
-      fprintf(stderr, "ERROR ZIP_ExtractFile could not find file in archive\n");
-      ErrLog_File("ERROR ZIP_ExtractFile could not find file in archive\n");
+      Log_Printf(LOG_ERROR, "ZIP_ExtractFile: could not find file in archive\n");
       return NULL;
     }
   
@@ -323,19 +387,22 @@ static char *ZIP_ExtractFile(unzFile uf, char *filename, uLong size)
   
   if (err!=UNZ_OK)
     {
-      fprintf(stderr, "ERROR ZIP_ExtractFile could not find file in archive\n");
-      ErrLog_File("ERROR ZIP_ExtractFile could not get file info\n");
+      Log_Printf(LOG_ERROR, "ZIP_ExtractFile: could not get file info\n");
       return NULL;
     }
   
   size_buf = size;
-  buf = Memory_Alloc(size_buf);
-  
+  buf = malloc(size_buf);
+  if (!buf)
+  {
+    perror("ZIP_ExtractFile");
+    return NULL;
+  }
+
   err = unzOpenCurrentFile(uf);
   if (err!=UNZ_OK)
     {
-      fprintf(stderr, "ERROR ZIP_ExtractFile could not find file in archive\n");
-      ErrLog_File("ERROR ZIP_ExtractFile could not open file\n");
+      Log_Printf(LOG_ERROR, "ZIP_ExtractFile: could not open file\n");
       return(NULL);
     }
   
@@ -344,8 +411,7 @@ static char *ZIP_ExtractFile(unzFile uf, char *filename, uLong size)
       err = unzReadCurrentFile(uf,buf,size_buf);
       if (err<0)	
 	{
-	  fprintf(stderr, "ERROR ZIP_ExtractFile could not find file in archive\n");
-	  ErrLog_File("ERROR ZIP_ExtractFile could not read file\n");
+	  Log_Printf(LOG_ERROR, "ZIP_ExtractFile: could not read file\n");
 	  return(NULL);
 	}
     } while (err>0);
@@ -358,14 +424,14 @@ static char *ZIP_ExtractFile(unzFile uf, char *filename, uLong size)
   Load .ZIP file into memory, return number of bytes loaded
 
 */
-Uint8 *ZIP_ReadDisc(char *pszFileName, char *pszZipPath, long *pImageSize)
+Uint8 *ZIP_ReadDisk(char *pszFileName, char *pszZipPath, long *pImageSize)
 {
   uLong ImageSize=0;
   unzFile uf=NULL;
   Uint8 *buf;
-  int nDiscType;
+  int nDiskType = -1;
   BOOL pathAllocated=FALSE;
-  Uint8 *pDiscBuffer = NULL;
+  Uint8 *pDiskBuffer = NULL;
 
   *pImageSize = 0;
 
@@ -387,7 +453,7 @@ Uint8 *ZIP_ReadDisc(char *pszFileName, char *pszZipPath, long *pImageSize)
       pathAllocated=TRUE;
     }
 
-  if((ImageSize = ZIP_CheckImageFile(uf, pszZipPath, &nDiscType)) <= 0)
+  if((ImageSize = ZIP_CheckImageFile(uf, pszZipPath, &nDiskType)) <= 0)
     {
       unzClose(uf);
       return NULL;
@@ -402,37 +468,37 @@ Uint8 *ZIP_ReadDisc(char *pszFileName, char *pszZipPath, long *pImageSize)
       return NULL;  /* failed extraction, return error */
     }
 
-  if (nDiscType == ZIP_FILE_ST)
+  if (nDiskType == ZIP_FILE_ST)
     {
       /* ST image => return buffer directly */
-      pDiscBuffer = buf;
+      pDiskBuffer = buf;
     }
-  else if (nDiscType == ZIP_FILE_MSA)
+  else if (nDiskType == ZIP_FILE_MSA)
     {
       /* uncompress the MSA file */
-      pDiscBuffer = MSA_UnCompress(buf, &ImageSize);
+      pDiskBuffer = MSA_UnCompress(buf, &ImageSize);
     }
-  else if (nDiscType == ZIP_FILE_DIM)
+  else if (nDiskType == ZIP_FILE_DIM)
     {
       /* Skip DIM header */
       ImageSize -= 32;
-      pDiscBuffer = malloc(ImageSize);
-      if (pDiscBuffer)
-        memcpy(pDiscBuffer, buf+32, ImageSize);
+      pDiskBuffer = malloc(ImageSize);
+      if (pDiskBuffer)
+        memcpy(pDiskBuffer, buf+32, ImageSize);
       else
-        perror("ZIP_ReadDisc");
+        perror("ZIP_ReadDisk");
     }
 
   /* Free the buffers */
-  if (pDiscBuffer != buf)
-    Memory_Free(buf);
+  if (pDiskBuffer != buf)
+    free(buf);
   if(pathAllocated == TRUE)
-    Memory_Free(pszZipPath);
+    free(pszZipPath);
 
-  if (pDiscBuffer != NULL)
+  if (pDiskBuffer != NULL)
     *pImageSize = ImageSize;
 
-  return(pDiscBuffer);
+  return pDiskBuffer;
 }
 
 
@@ -442,7 +508,7 @@ Uint8 *ZIP_ReadDisc(char *pszFileName, char *pszZipPath, long *pImageSize)
   
   Not yet implemented.
 */
-BOOL ZIP_WriteDisc(char *pszFileName,unsigned char *pBuffer,int ImageSize)
+BOOL ZIP_WriteDisk(char *pszFileName,unsigned char *pBuffer,int ImageSize)
 {
   return(FALSE);
 }
